@@ -25,7 +25,7 @@
 *   59 Temple Place, Suite 330, Boston, MA 02111-1307, USA
 * ؼ񤤤Ƥ
 * 
-* $Id: amenu.h,v 1.17 2009/01/04 00:24:51 bowkenken Exp $
+* $Id: amenu.h,v 1.18 2009/06/01 05:05:04 bowkenken Exp $
 ***************************************************************/
 
 #ifndef	AMENU_H
@@ -42,8 +42,14 @@
 
 /* ȥκʸ */
 #define	MSG_TTL_AUTO_MARK_MAX_LEN	64
+#define	MSG_TTL_AUTO_MARK_MAX_BYTE	\
+	(MSG_TTL_AUTO_MARK_MAX_LEN * CHAR_MAX_LEN_UTF_8)
 #define	MSG_TTL_AUTO_MARK_INFO_MAX_LEN	30
+#define	MSG_TTL_AUTO_MARK_INFO_MAX_BYTE	\
+	(MSG_TTL_AUTO_MARK_INFO_MAX_LEN * CHAR_MAX_LEN_UTF_8)
 #define	MSG_TTL_AUTO_MARK_HINT_MAX_LEN	30
+#define	MSG_TTL_AUTO_MARK_HINT_MAX_BYTE	\
+	(MSG_TTL_AUTO_MARK_HINT_MAX_LEN * CHAR_MAX_LEN_UTF_8)
 
 /* ƥμκ */
 #define	AUTO_MARK_APPOINT_ITEM_MAX_N	64
