@@ -6,6 +6,8 @@ extern "C" {
 
 void	gui_begin( void );
 void	gui_end( void );
+void	key_buf_lock( void );
+void	key_buf_unlock( void );
 bool_t	call_game_thread_create( void *(*func)( void * ) );
 bool_t	call_game_thread_exit(
 	void *(*func)( void * ), long code
@@ -79,6 +81,7 @@ bool_t	call_pcg_dun_clip_win_x( long mapX, bool_t flg_gui );
 bool_t	call_pcg_dun_clip_win_y( long mapY, bool_t flg_gui );
 void	call_demo_last_boss_reset( void );
 bool_t	call_demo_last_boss_check_done( void );
+void	call_demo_ending_skip_scene( void );
 void	call_game_music_play_scene( bool_t flg_gui );
 void	call_game_music_play( long kind, long idx );
 void	call_game_music_replay( void );
