@@ -25,7 +25,7 @@
 *   59 Temple Place, Suite 330, Boston, MA 02111-1307, USA
 * ؼ񤤤Ƥ
 * 
-* $Id: curs.h,v 1.40 2009/06/21 14:55:30 bowkenken Exp $
+* $Id: curs.h,v 1.41 2009/08/09 07:37:02 bowkenken Exp $
 ***************************************************************/
 
 #ifndef	CURS_H
@@ -122,7 +122,9 @@ typedef struct {
 * ̥
 ***************************************************************/
 
-#define	SCREEN_SIZE_MIN_LINES	22
-#define	SCREEN_SIZE_MAX_LINES	128
+#define	SCREEN_SIZE_MIN_COL	(2 + 1 + 1)
+#define	SCREEN_SIZE_MAX_COL	(1024 * 2)
+#define	SCREEN_SIZE_MIN_ROW	(1 + 1 + 1)
+#define	SCREEN_SIZE_MAX_ROW	1024
 
 #endif	/* CURS_H */
