@@ -25,7 +25,7 @@
 *   59 Temple Place, Suite 330, Boston, MA 02111-1307, USA
 * ؼ񤤤Ƥ
 * 
-* $Id: dun.c,v 1.155 2009/08/21 11:34:13 bowkenken Exp $
+* $Id: dun.c,v 1.157 2009/09/06 15:35:51 bowkenken Exp $
 ***************************************************************/
 
 /***************************************************************
@@ -469,6 +469,7 @@ void	reset_all( bool_t flg_appear )
 	garbage_collection_all_item();
 	reset_trap();
 	reset_mnstr();
+	reset_spell();
 	release_all_mbr();
 
 	clr_map_all_mbr();
@@ -4235,7 +4236,7 @@ bool_t	clip_draw_x( long n )
 		}
 	}
 	if( g_flg_gui ){
-		if( call_pcg_dun_clip_win_x( n ) )
+		if( call_pcg_dun_clip_win_x( n, FALSE ) )
 			return TRUE;
 	}
 
@@ -4263,7 +4264,7 @@ bool_t	clip_draw_y( long n )
 		}
 	}
 	if( g_flg_gui ){
-		if( call_pcg_dun_clip_win_y( n ) )
+		if( call_pcg_dun_clip_win_y( n, FALSE ) )
 			return TRUE;
 	}
 
