@@ -25,7 +25,7 @@
 *   59 Temple Place, Suite 330, Boston, MA 02111-1307, USA
 * ؼ񤤤Ƥ
 * 
-* $Id: ending-ep.c,v 1.9 2009/08/29 17:55:55 bowkenken Exp $
+* $Id: ending-ep.c,v 1.10 2009/09/12 19:47:57 bowkenken Exp $
 ***************************************************************/
 
 /***************************************************************
@@ -40,6 +40,7 @@
 ***************************************************************/
 
 static scene_n_t	pre_scene;
+static bool_t	g_flg_skip_scene;
 check_memory_def( check_memory_ending_ep_c_pre_scene )
 
 #define	EPILOGUE_MAX_LEN	40
@@ -69,6 +70,7 @@ check_memory_def( check_memory_ending_ep_c_FRAME_PER_CHAR )
 
 void	init_ending( void )
 {
+	set_flg_skip_scene_ending( FALSE );
 	init_space();
 	init_epilogue();
 }
@@ -182,7 +184,11 @@ bool_t	draw_ending( void )
 		// 
 		draw_epilogue();
 
-		if( time( NULL ) > wait_time ){
+		if( get_flg_skip_scene_ending()
+				|| (time( NULL ) > wait_time) ){
+			set_flg_skip_scene_ending( FALSE );
+			wipe_all();
+
 			// ڤؤ
 			if( !g_flg_gui ){
 				wait_time = 0;
@@ -206,7 +212,11 @@ bool_t	draw_ending( void )
 		// 
 		draw_space( FALSE );
 
-		if( time( NULL ) > wait_time ){
+		if( get_flg_skip_scene_ending()
+				|| (time( NULL ) > wait_time) ){
+			set_flg_skip_scene_ending( FALSE );
+			wipe_all();
+
 			// ڤؤ
 			if( !g_flg_gui ){
 				wait_time = 0;
@@ -218,6 +228,16 @@ bool_t	draw_ending( void )
 	// åա
 
 	if( get_scene() == SCENE_N_ENDING_STAFF_ROLL ){
+		if( get_flg_skip_scene_ending() ){
+			set_flg_skip_scene_ending( FALSE );
+			wipe_all();
+
+			// ڤؤ
+			if( !g_flg_gui ){
+				change_scene( SCENE_N_ENDING_END );
+			}
+		}
+
 		// 
 		return draw_space( TRUE );
 	}
@@ -225,6 +245,10 @@ bool_t	draw_ending( void )
 	// The End
 
 	if( get_scene() == SCENE_N_ENDING_END ){
+		// 
+		if( pre_scene != SCENE_N_ENDING_END )
+			wipe_all();
+
 		// 
 		return draw_space( TRUE );
 	}
@@ -232,6 +256,26 @@ bool_t	draw_ending( void )
 	return TRUE;
 }
 
+/***************************************************************
+* ǥ󥰤Υ򥹥å
+* bool_t flg : åפ뤫?
+***************************************************************/
+
+void	set_flg_skip_scene_ending( bool_t flg )
+{
+	g_flg_skip_scene = flg;
+}
+
+/***************************************************************
+* ǥ󥰤Υ򥹥åפ뤫Ĵ٤
+* return : åפ뤫?
+***************************************************************/
+
+bool_t	get_flg_skip_scene_ending( void )
+{
+	return g_flg_skip_scene;
+}
+
 /***************************************************************
 * ԥ
 * return : 顼̵ä?
