@@ -25,7 +25,7 @@
 *   59 Temple Place, Suite 330, Boston, MA 02111-1307, USA
 * ؼ񤤤Ƥ
 * 
-* $Id: fight.c,v 1.155 2009/02/17 00:56:59 bowkenken Exp $
+* $Id: fight.c,v 1.168 2009/09/13 17:08:17 bowkenken Exp $
 ***************************************************************/
 
 /***************************************************************
@@ -87,12 +87,12 @@
 
 /* 󥯤Υ٥˴ */
 
-#define	HIT_MON_MUL	10
-#define	HIT_MON_ADD	20
-#define	DAM_MON_MUL	10
-#define	DAM_MON_ADD	20
-#define	DEF_MON_MUL	10
-#define	DEF_MON_ADD	20
+#define	HIT_MON_MUL	6
+#define	HIT_MON_ADD	2
+#define	DAM_MON_MUL	6
+#define	DAM_MON_ADD	2
+#define	DEF_MON_MUL	6
+#define	DEF_MON_ADD	2
 
 /* դΥƥ롦ҥåΨ */
 
@@ -166,6 +166,7 @@ static attack_t	mbr_attack_bash[] = {
 		SPELL_KIND_NULL,
 		EXTENT_KIND_NULL, N_MSG_NULL, },
 };
+check_memory_def( check_memory_fight_c_mbr_attack_bash )
 
 /***************************************************************
 * ƥꤲιǡ
@@ -185,6 +186,7 @@ static attack_t	mbr_attack_throw[] = {
 		SPELL_KIND_NULL,
 		EXTENT_KIND_NULL, N_MSG_NULL, },
 };
+check_memory_def( check_memory_fight_c_mbr_attack_throw )
 
 /***************************************************************
 * ꤲιǡ
@@ -204,6 +206,7 @@ static attack_t	mbr_attack_throw_light[] = {
 		SPELL_KIND_NULL,
 		EXTENT_KIND_NULL, N_MSG_NULL, },
 };
+check_memory_def( check_memory_fight_c_mbr_attack_throw_light )
 
 /***************************************************************
 * ƥåѿꥻå
@@ -309,7 +312,7 @@ bool_t	set_attack_mbr_bash(
 	} else {
 		/* ξ */
 		p = get_attack( flg_ave, wpn_tab->attack, range,
-				TRUE, FALSE, FALSE, FALSE );
+				TRUE, TRUE, FALSE, FALSE );
 		if( p == NULL )
 			return FALSE;
 		*attack = *p;
@@ -376,8 +379,6 @@ bool_t	fight_throw( chr_t *chr1, chr_t *chr2, attack_t *dflt_attack )
 
 	if( chr1 == NULL )
 		return FALSE;
-	if( chr2 == NULL )
-		return FALSE;
 
 	if( is_mbr( chr1 ) ){
 		eq = get_mbr_item_asgn_equip( chr1 );
@@ -670,6 +671,9 @@ attack_t	*get_attack_ave(
 		ave.hit += ls[i].hit * n;
 		ave.crtcl += ls[i].crtcl * n;
 		ave.dam += ls[i].dam * n;
+
+		ave.flg_throw = ls[i].flg_throw;
+		ave.flg_monk = ls[i].flg_monk;
 	}
 
 	if( sum <= 0 )
@@ -861,11 +865,9 @@ bool_t	fight(
 	for( i = 0; i < attack_n; i++ ){
 		if( fight_x_1( o_p, d_p, attack, range, FALSE ) ){
 			hit_n++;
-		} else {
-			if( fight_two_sword_fencing( o_p, d_p,
-					attack, range ) ){
-				hit_n++;
-			}
+		} else if( fight_two_sword_fencing( o_p, d_p,
+				attack, range ) ){
+			hit_n++;
 		}
 	}
 
@@ -1057,28 +1059,31 @@ long	calc_two_sword_fencing_n( chr_t *o_p, const attack_t *attack )
 	abl_kind_t	abl;
 	long	lev;
 	rate_t	rate;
+	long	min_n;
+
+	min_n = SKILL_TWO_SWORD_FENCING_MIN_N;
 
 	if( o_p == NULL )
-		return SKILL_TWO_SWORD_FENCING_MIN_N;
+		return min_n;
 	if( !is_mbr( o_p ) )
-		return SKILL_TWO_SWORD_FENCING_MIN_N;
+		return min_n;
 	if( attack == NULL )
-		return SKILL_TWO_SWORD_FENCING_MIN_N;
+		return min_n;
 	if( attack->flg_throw )
-		return SKILL_TWO_SWORD_FENCING_MIN_N;
+		return min_n;
 	if( attack->flg_monk )
-		return SKILL_TWO_SWORD_FENCING_MIN_N;
+		return min_n;
 
 	if( !chk_ena_skill( o_p, SKILL_KIND_TWO_SWORD_FENCING ) )
-		return SKILL_TWO_SWORD_FENCING_MIN_N;
+		return min_n;
 
 	eq = get_mbr_item_asgn_equip( (mbr_t *)o_p );
 	if( eq == NULL )
-		return SKILL_TWO_SWORD_FENCING_MIN_N;
+		return min_n;
 	if( eq[EQUIP_KIND_WIELDING].kind != ITEM_KIND_WPN )
-		return SKILL_TWO_SWORD_FENCING_MIN_N;
+		return min_n;
 	if( eq[EQUIP_KIND_SHIELD].kind != ITEM_KIND_WPN )
-		return SKILL_TWO_SWORD_FENCING_MIN_N;
+		return min_n;
 
 	abl = (abl_kind_t)(ABL_KIND_MAX_N + SKILL_KIND_TWO_SWORD_FENCING);
 	lev = get_lev( o_p, abl );
@@ -1109,8 +1114,8 @@ bool_t	fight_x_1(
 	chr_kind_t	o_k, d_k;
 	long	o_hit, o_dam, o_dam_real;
 	rate_t	o_crtcl;
-	static char	o_name[CHR_NAME_MAX_LEN + 1];
-	static char	d_name[CHR_NAME_MAX_LEN + 1];
+	static char	o_name[CHR_NAME_MAX_BYTE + 1];
+	static char	d_name[CHR_NAME_MAX_BYTE + 1];
 	rate_t	o_skill_dam;
 	long	d_def, d_ac;
 	rate_t	d_resi;
@@ -1129,6 +1134,7 @@ bool_t	fight_x_1(
 	bool_t	flg_catch_food;
 	char	mjr;
 	item_t	arw;
+	sound_kind_t	sk;
 
 	if( attack == NULL )
 		return FALSE;
@@ -1157,7 +1163,7 @@ bool_t	fight_x_1(
 
 	/* ¦̾μ */
 
-	str_nz_cpy( o_name, o_p->name, CHR_NAME_MAX_LEN );
+	str_nz_cpy( o_name, o_p->name, CHR_NAME_MAX_BYTE );
 
 	/* ξǤƮϽʤ */
 
@@ -1240,13 +1246,13 @@ bool_t	fight_x_1(
 	/* ɸ¦̾ȥǡμ */
 
 	if( flg_d_null ){
-		str_nz_cpy( d_name, MSG_NULL, CHR_NAME_MAX_LEN );
+		str_nz_cpy( d_name, MSG_NULL, CHR_NAME_MAX_BYTE );
 		d_hp = NULL;
 		d_fx = NULL;
-		d_x = 0;
-		d_y = 0;
+		d_x = o_p->trgt.true_x;
+		d_y = o_p->trgt.true_y;
 	} else {
-		str_nz_cpy( d_name, d_p->name, CHR_NAME_MAX_LEN );
+		str_nz_cpy( d_name, d_p->name, CHR_NAME_MAX_BYTE );
 		d_hp = &(d_p->abl.hp);
 		d_fx = &(d_p->fx);
 		d_x = d_p->x;
@@ -1294,7 +1300,18 @@ bool_t	fight_x_1(
 
 	/* ꤬Ƥ뤫 */
 
-	if( !flg_d_null ){
+	if( flg_d_null ){
+		pos_t	o_pos, d_pos;
+
+		o_pos.x = o_p->x;
+		o_pos.y = o_p->y;
+		d_pos.x = o_p->trgt.true_x;
+		d_pos.y = o_p->trgt.true_y;
+		if( !chk_find( &o_pos, &d_pos ) ){
+			clr_chr_trgt_act( o_p, FALSE );
+			return FALSE;
+		}
+	} else {
 		if( !chk_find_chr( o_p, d_p ) ){
 			if( o_k == CHR_KIND_MBR ){
 				print_msg( FLG_MSG_ERR,
@@ -1305,7 +1322,10 @@ bool_t	fight_x_1(
 		}
 	}
 
-	print_msg( FLG_NULL, get_msg_attack( attack ), o_name, d_name );
+	print_msg_find( d_p, FLG_NULL, get_msg_attack( attack ),
+			o_name, d_name );
+	print_msg_find( d_p, FLG_NULL, MSG_FIGHT_RESI_KIND,
+			get_resi_name( attack->resi_kind ) );
 
 	bgn.x = o_p->x;
 	bgn.y = o_p->y;
@@ -1314,6 +1334,16 @@ bool_t	fight_x_1(
 
 	mjr = MNSTR_THROW_MJR;
 	if( attack->flg_throw ){
+		sound_kind_t	sk;
+
+		if( o_k == CHR_KIND_MBR )
+			sk = SOUND_KIND_FIGHT_ATTACK_THROW_MEMBER;
+		else if( o_k == CHR_KIND_MNSTR )
+			sk = SOUND_KIND_FIGHT_ATTACK_THROW_MONSTER;
+		else
+			sk = SOUND_KIND_NULL;
+		call_game_sound_play( sk, 1 );
+
 		/* ꤲʪ */
 		if( (o_k == CHR_KIND_MBR) && (eq != NULL) )
 			mjr = get_item_mjr( &(eq[EQUIP_KIND_ARW]) );
@@ -1427,6 +1457,21 @@ bool_t	fight_x_1(
 	/* ʤ */
 
 	if( flg_d_null || (!flg_crtcl && (d_def > o_hit)) ){
+		sound_kind_t	sk;
+
+		if( flg_d_null ){
+			sk = SOUND_KIND_NULL;
+		} else if( is_xx( d_p ) ){
+			sk = SOUND_KIND_FIGHT_DEFENSE_MISS_MONSTER_BOSS_LAST;
+		} else if( is_mnstr( d_p ) ){
+			sk = SOUND_KIND_FIGHT_DEFENSE_MISS_MONSTER;
+		} else if( is_mbr( d_p ) ){
+			sk = SOUND_KIND_FIGHT_DEFENSE_MISS_MEMBER;
+		} else {
+			sk = SOUND_KIND_NULL;
+		}
+		call_game_sound_play( sk, 1 );
+
 		if( flg_d_null ){
 			print_msg( FLG_MSG_ERR, MSG_ERR_MNSTR_NULL );
 		} else {
@@ -1464,8 +1509,18 @@ bool_t	fight_x_1(
 
 	/* 񤹤 */
 
-	if( attack->flg_throw && (eq != NULL) && (o_k == CHR_KIND_MBR) ){
-		if( (eq[EQUIP_KIND_ARW].kind == ITEM_KIND_WPN)
+	do {
+		if( !attack->flg_throw )
+			break;
+		if( eq == NULL )
+			break;
+		if( o_k != CHR_KIND_MBR )
+			break;
+
+		if( flg_d_null ){
+			/* 񤻤 */
+			dec_throw( (mbr_t *)o_p, TRUE, d_x, d_y );
+		} else if( (eq[EQUIP_KIND_ARW].kind == ITEM_KIND_WPN)
 				&& chk_flg( eq[EQUIP_KIND_ARW].dat.wpn.flg,
 				FLG_WPN_TAB_NOT_SPEND ) ){
 			/* 񤻤 */
@@ -1473,7 +1528,9 @@ bool_t	fight_x_1(
 		} else {
 			dec_throw( (mbr_t *)o_p, FALSE, d_x, d_y );
 		}
-	}
+
+		break;
+	} while( 0 );
 
 	/* Ƥ */
 
@@ -1523,6 +1580,29 @@ bool_t	fight_x_1(
 		if( o_dam_real > d_hp->n )
 			o_dam_real = d_hp->n;
 
+	/* ̲ */
+
+	sk = SOUND_KIND_NULL;
+	if( o_dam <= 0 ){
+		sk = SOUND_KIND_NULL;
+	} else if( flg_ninja_crtcl ){
+		if( is_mnstr( d_p ) )
+			sk = SOUND_KIND_FIGHT_DEFENSE_CRITICAL_MONSTER;
+		else
+			sk = SOUND_KIND_FIGHT_DEFENSE_CRITICAL_MEMBER;
+	} else if( flg_crtcl ){
+		if( is_mnstr( d_p ) )
+			sk = SOUND_KIND_FIGHT_DEFENSE_CRITICAL_MONSTER;
+		else
+			sk = SOUND_KIND_FIGHT_DEFENSE_CRITICAL_MEMBER;
+	} else {
+		if( is_mnstr( d_p ) )
+			sk = SOUND_KIND_FIGHT_DEFENSE_HIT_MONSTER;
+		else
+			sk = SOUND_KIND_FIGHT_DEFENSE_HIT_MEMBER;
+	}
+	call_game_sound_play( sk, 1 );
+
 	/* ᡼ɽ */
 
 	if( o_dam <= 0 ){
@@ -1532,13 +1612,13 @@ bool_t	fight_x_1(
 		print_msg( FLG_NULL, MSG_FIGHT_CRTCL_NINJA, o_name );
 		curs_attrset_dflt();
 
-		vfx_ninja_crtcl( d_k, end.x, end.y );
+		vfx_ninja_crtcl( d_p, end.x, end.y );
 	} else if( flg_crtcl ){
 		curs_attrset_chr( d_p, -1, TRUE );
 		print_msg( FLG_NULL, MSG_FIGHT_CRTCL_STD, o_name );
 		curs_attrset_dflt();
 
-		vfx_crtcl( d_k, end.x, end.y );
+		vfx_crtcl( d_p, end.x, end.y );
 
 		curs_attrset_chr( d_p, -1, FALSE );
 		print_msg( FLG_NULL, MSG_FIGHT_HIT_STD,
@@ -1550,7 +1630,7 @@ bool_t	fight_x_1(
 				d_name, o_dam_real );
 		curs_attrset_dflt();
 
-		vfx_hit( d_k, end.x, end.y );
+		vfx_hit( d_p, end.x, end.y );
 	}
 
 	/* Υե */
@@ -1738,8 +1818,8 @@ bool_t	spell_attack(
 {
 	flg_stat_t	o_stat;
 	pos_t	o_pos, d_pos;
-	static char	o_name[CHR_NAME_MAX_LEN + 1];
-	static char	d_name[CHR_NAME_MAX_LEN + 1];
+	static char	o_name[CHR_NAME_MAX_BYTE + 1];
+	static char	d_name[CHR_NAME_MAX_BYTE + 1];
 	rate_t	o_skill_dam;
 	long	dam;
 	long	ac;
@@ -1782,13 +1862,13 @@ bool_t	spell_attack(
 	o_stat = o_p->stat;
 	o_pos.x = o_p->x;
 	o_pos.y = o_p->y;
-	str_nz_cpy( o_name, o_p->name, CHR_NAME_MAX_LEN );
+	str_nz_cpy( o_name, o_p->name, CHR_NAME_MAX_BYTE );
 
 	/* ɸ¦ǡ */
 
 	d_pos.x = d_p->x;
 	d_pos.y = d_p->y;
-	str_nz_cpy( d_name, d_p->name, CHR_NAME_MAX_LEN );
+	str_nz_cpy( d_name, d_p->name, CHR_NAME_MAX_BYTE );
 
 	/* Ǥ뤫 */
 
@@ -1849,6 +1929,9 @@ bool_t	spell_attack(
 
 	/* ᡼ɽ */
 
+	print_msg_find( d_p, FLG_NULL, MSG_FIGHT_RESI_KIND,
+			get_resi_name( resi ) );
+
 	curs_attrset_chr( d_p, -1, FALSE );
 	print_msg_find( d_p, FLG_NULL, MSG_FIGHT_HIT_STD, d_name, dam );
 	curs_attrset_dflt();
@@ -2137,7 +2220,7 @@ bool_t	chr_break_item( chr_t *chr, item_t *item )
 {
 	long	hit;
 	attack_t	attack;
-	char	name[ITEM_NAME_MAX_LEN + 1];
+	char	name[ITEM_NAME_MAX_BYTE + 1];
 
 	if( chr == NULL )
 		return FALSE;
@@ -2165,7 +2248,7 @@ bool_t	chr_break_item( chr_t *chr, item_t *item )
 		return FALSE;
 	}
 
-	str_nz_cpy( name, item->name, ITEM_NAME_MAX_LEN );
+	str_nz_cpy( name, item->name, ITEM_NAME_MAX_BYTE );
 
 	break_item_contents( item, chr );
 	if( break_item( item, TRUE ) )
@@ -3309,3 +3392,17 @@ char	*get_msg_attack( const attack_t *attack )
 
 	return MSG_NULL;
 }
+
+/***************************************************************
+* ꡼å
+***************************************************************/
+
+void	check_memory_fight_c( void )
+{
+	check_memory( check_memory_fight_c_mbr_attack_bash,
+			"fight.c: mbr_attack_bash" );
+	check_memory( check_memory_fight_c_mbr_attack_throw,
+			"fight.c: mbr_attack_throw" );
+	check_memory( check_memory_fight_c_mbr_attack_throw_light,
+			"fight.c: mbr_attack_throw_light" );
+}
