@@ -25,7 +25,7 @@
 *   59 Temple Place, Suite 330, Boston, MA 02111-1307, USA
 * ؼ񤤤Ƥ
 * 
-* $Id: gf-conf.c,v 1.25 2009/08/21 10:33:54 bowkenken Exp $
+* $Id: gf-conf.c,v 1.27 2009/09/11 15:46:19 bowkenken Exp $
 ***************************************************************/
 
 /***************************************************************
@@ -108,6 +108,10 @@ bool_t	load_game_conf( void )
 	if( fclose( fp ) == EOF )
 		return TRUE;
 
+	/* ޥɡ饤ͥ */
+
+	overwrite_arg();
+
 	/* 顼åɽ */
 
 	if( flg_err ){
@@ -1337,7 +1341,7 @@ bool_t	load_game_conf_set_macro_func(
 			return FALSE;
 
 		for( j = 0; j < JOY_KIND_MAX_N; j++ ){
-			if( strcmp( joy, cv_joystick_kind_to_name( j ) )
+			if( strcmp( joy, cv_joystick_kind_to_name( (joy_kind_t)j ) )
 					== 0 ){
 				m = get_macro_joystick( j, n );
 				break;
@@ -1535,6 +1539,10 @@ bool_t	load_game_data_cnf( long n )
 	if( !chk_load_game_data_cnf() )
 		return FALSE;
 
+	/* ޥɡ饤ͥ */
+
+	overwrite_arg();
+
 	return TRUE;
 }
 
@@ -2593,7 +2601,7 @@ bool_t	save_game_conf_func( FILE *fp, const ver_t *ver )
 			if( m == NULL )
 				break;
 
-			joy_name = cv_joystick_kind_to_name( j );
+			joy_name = cv_joystick_kind_to_name( (joy_kind_t)j );
 			if( joy_name == NULL )
 				continue;
 
