@@ -43,6 +43,8 @@ void	rc_lex_id( FILE *fp, rc_union_t *u, bool_t flg_err_exit );
 long	rc_lex_getc( FILE *fp, bool_t flg_chk_eof, bool_t flg_err_exit );
 void	rc_lex_ungetc( FILE *fp, long c );
 bool_t	rename_back_up_file( char *fname );
+square_dir_t	trans_idx_to_square_dir( long idx );
+long	trans_square_dir_to_idx( square_dir_t dir );
 chr_kind_t	trans_idx_to_chr_kind( long idx );
 long	trans_chr_kind_to_idx( chr_kind_t k );
 main_race_t	trans_idx_to_main_race_kind( long idx );
@@ -158,6 +160,7 @@ long	load_crypt_str( FILE *fp, char *buf, long n );
 long	load_crypt_c( FILE *fp );
 long	load_crypt_c_sub( FILE *fp );
 void	un_load_crypt_c( FILE *fp, long c );
+void	check_memory_gfile_c( void );
 
 #ifdef __cplusplus
 }
@@ -186,6 +189,14 @@ bool_t	load_game_conf_id_char_str(
 	FILE *fp, const ver_t *ver, bool_t flg_err_exit,
 	char *id, long c, char *str
 );
+bool_t	load_game_conf_id_num_str(
+	FILE *fp, const ver_t *ver, bool_t flg_err_exit,
+	char *id, long n, char *str
+);
+bool_t	load_game_conf_id_str_num_str(
+	FILE *fp, const ver_t *ver, bool_t flg_err_exit,
+	char *id, char *str1, long n, char *str2
+);
 bool_t	load_game_conf_id_char(
 	FILE *fp, const ver_t *ver, bool_t flg_err_exit,
 	char *id, long c
@@ -197,7 +208,10 @@ bool_t	load_game_conf_id_brace(
 bool_t	load_game_conf_lang( char *id, char *str );
 bool_t	load_game_conf_clk_tck( char *id, long val );
 bool_t	load_game_conf_screen_size_auto( char *id, long val );
-bool_t	load_game_conf_screen_size_lines( char *id, long val );
+bool_t	load_game_conf_screen_size_col( char *id, long val );
+bool_t	load_game_conf_screen_size_row( char *id, long val );
+bool_t	load_game_conf_screen_size_message( char *id, long val );
+bool_t	load_game_conf_screen_resize_map( char *id, long val );
 bool_t	load_game_conf_scroll( char *id, char *str );
 bool_t	load_game_conf_joystick_kind( char *id, char *str );
 bool_t	load_game_conf_clr_key_buf_every( char *id, long val );
@@ -205,6 +219,7 @@ bool_t	load_game_conf_clr_key_buf_menu( char *id, long val );
 bool_t	load_game_conf_space_select( char *id, long val );
 bool_t	load_game_conf_redraw_every_turn( char *id, long val );
 bool_t	load_game_conf_mul_line( char *id, long val );
+bool_t	load_game_conf_move_crsr_dflt( char *id, long val );
 bool_t	load_game_conf_joystick_number( char *id, long val );
 bool_t	load_game_conf_gnome( char *id, long val );
 bool_t	load_game_conf_set_window_position( char *id, long val );
@@ -221,6 +236,9 @@ bool_t	load_game_conf_attribute_blink( char *id, long val );
 bool_t	load_game_conf_attribute_bold( char *id, long val );
 bool_t	load_game_conf_set_key( char *id, long c, char *str );
 bool_t	load_game_conf_unset_key( char *id, long c );
+bool_t	load_game_conf_set_macro_func(
+	char *id, char *joy, long n, char *macro
+);
 bool_t	load_game_conf_menu(
 	FILE *fp, const ver_t *ver, bool_t flg_err_exit,
 	char *id
@@ -263,6 +281,15 @@ bool_t	save_game_conf_color_sub(
 );
 bool_t	save_game_conf_user_menu( FILE *fp, const ver_t *ver );
 bool_t	save_game_conf_key_tab( FILE *fp, const ver_t *ver );
+bool_t	save_game_conf_func( FILE *fp, const ver_t *ver );
+bool_t	save_game_conf_func_sub(
+	FILE *fp,
+	const ver_t *ver,
+	const char *tag,
+	const char *joy,
+	long n,
+	const char *macro
+);
 bool_t	save_game_data_cnf_ver_1( const ver_t *ver, long n );
 bool_t	save_game_data_cnf_contents(
 	FILE *fp, const ver_t *ver
@@ -273,6 +300,7 @@ const char	*cv_joystick_kind_to_name( joy_kind_t k );
 joy_kind_t	cv_joystick_name_to_kind( const char *name );
 char	*cv_color_to_name( int color );
 int	cv_name_to_color( char *name );
+void	check_memory_gf_conf_c( void );
 
 #ifdef __cplusplus
 }
@@ -288,6 +316,7 @@ bool_t	load_crsr_ptn_head( FILE *fp, crsr_ptn_t *ptn );
 bool_t	load_crsr_ptn_misc( FILE *fp, crsr_ptn_t *ptn );
 bool_t	load_crsr_ptn_data( FILE *fp, crsr_ptn_t *ptn );
 bool_t	save_crsr_ptn( crsr_ptn_t *ptn, long max_n );
+void	check_memory_gf_crsr_c( void );
 
 #ifdef __cplusplus
 }
@@ -318,6 +347,7 @@ bool_t	load_graph_conf_set_str(
 	FILE *fp, const ver_t *ver, bool_t flg_err_exit,
 	char *id, char *str
 );
+void	check_memory_gf_gconf_c( void );
 
 #ifdef __cplusplus
 }
@@ -330,6 +360,7 @@ extern "C" {
 
 char	*get_out_map_file_name( char *s );
 bool_t	out_map_file( void );
+void	check_memory_gf_outmap_c( void );
 
 #ifdef __cplusplus
 }
@@ -363,6 +394,7 @@ bool_t	save_game_replay_ver_1( const ver_t *ver, long n );
 bool_t	save_game_replay_contents(
 	FILE *fp, const ver_t *ver, long n
 );
+void	check_memory_gf_replay_c( void );
 
 #ifdef __cplusplus
 }
@@ -374,11 +406,15 @@ extern "C" {
 #endif
 
 bool_t	load_game_data( bool_t flg_txt, long n );
+void	set_flg_exit_shop( bool_t flg );
+bool_t	get_flg_exit_shop( void );
+void	appear_load_game_data( long slot_n );
 void	ver_up_game_data_1_0_4( void );
 void	ver_up_game_data_1_1_1( void );
 void	ver_up_game_data_1_1_3( void );
 void	ver_up_game_data_1_2_6( void );
 void	ver_up_game_data_1_2_12( void );
+void	ver_up_game_data_1_2_27( void );
 void	reset_load_game_data( void );
 bool_t	chk_load_game_data( void );
 bool_t	load_game_data_head_ver_1( FILE *fp, ver_t *ver, bool_t flg_txt );
@@ -402,6 +438,9 @@ bool_t	load_game_data_block_ver_1(
 	FILE *fp, const ver_t *ver, bool_t flg_txt,
 	char *id, long n
 );
+bool_t	load_game_data_square_ver_1(
+	FILE *fp, const ver_t *ver, bool_t flg_txt
+);
 bool_t	load_game_data_class_ver_1(
 	FILE *fp, const ver_t *ver, bool_t flg_txt,
 	long n
@@ -593,6 +632,9 @@ bool_t	save_game_data_dun_lev_ver_1(
 bool_t	save_game_data_turn_ver_1(
 	FILE *fp, const ver_t *ver, bool_t flg_txt
 );
+bool_t	save_game_data_square_ver_1(
+	FILE *fp, const ver_t *ver, bool_t flg_txt
+);
 bool_t	save_game_data_class_ver_1(
 	FILE *fp, const ver_t *ver, bool_t flg_txt
 );
@@ -767,6 +809,7 @@ bool_t	get_game_data_head_time(
 	char *str, long n,
 	bool_t flg_txt, bool_t flg_replay
 );
+void	check_memory_gf_save_c( void );
 
 #ifdef __cplusplus
 }
@@ -785,6 +828,7 @@ bool_t	save_town_ptn( town_ptn_t *ptn );
 void	save_town_ptn_col_1byte( FILE *fp, town_ptn_t *ptn );
 void	save_town_ptn_col_2byte( FILE *fp );
 void	back_up_town_ptn( void );
+void	check_memory_gf_town_c( void );
 
 #ifdef __cplusplus
 }
