@@ -19,10 +19,10 @@ void	init_ls_menu_macro_joystick( void );
 bool_t	chk_executing_menu( void );
 char	*exec_menu( menu_t *p, menu_t *dflt, char *str_goto );
 char	*exec_menu_sub( menu_t *p, menu_t *dflt, char *str_goto );
-void	clr_menu_current_pass( void );
-const char	*get_menu_current_pass( void );
-void	push_menu_current_pass( const char *path );
-void	pop_menu_current_pass( void );
+void	clr_menu_current_path( void );
+const char	*get_menu_current_path( void );
+void	push_menu_current_path( const char *path );
+void	pop_menu_current_path( void );
 void	set_flg_menu_dflt( bool_t flg );
 bool_t	get_flg_menu_dflt( void );
 bool_t	chk_err_menu_kind( menu_t *ls );
