@@ -25,7 +25,7 @@
 *   59 Temple Place, Suite 330, Boston, MA 02111-1307, USA
 * ؼ񤤤Ƥ
 * 
-* $Id: menu-tab.h,v 1.24 2009/06/01 05:05:04 bowkenken Exp $
+* $Id: menu-tab.h,v 1.26 2009/08/16 04:20:27 bowkenken Exp $
 ***************************************************************/
 
 #ifndef	MENU_TAB_H
@@ -139,9 +139,21 @@ menu_t	ls_menu_ask[] = {
 	},
 };
 
-menu_t	ls_menu_func[
-	1 + 1 + (5 * FUNC_KEY_MAX)
-	+ FUNC_KEY_MAX / MENU_FUNC_MAX_N_PER_PAGE
+menu_t	ls_menu_macro_func[
+	1 + 1 + (5 * KEY_N_FUNC_MAX_N)
+	+ (KEY_N_FUNC_MAX_N / MENU_MACRO_FUNC_MAX_N_PER_PAGE)
+	+ 1
+];
+
+menu_t	ls_menu_macro_mouse[
+	1 + 1 + (5 * KEY_N_MOUSE_MAX_N)
+	+ (2 * KEY_N_MOUSE_MAX_N / MENU_MACRO_MOUSE_MAX_N_PER_PAGE)
+	+ 1
+];
+
+menu_t	ls_menu_macro_joystick[
+	1 + 1 + (5 * KEY_N_JOYSTICK_MAX_N)
+	+ (2 * KEY_N_JOYSTICK_MAX_N / MENU_MACRO_JOYSTICK_MAX_N_PER_PAGE)
 	+ 1
 ];
 
