@@ -25,7 +25,7 @@
 *   59 Temple Place, Suite 330, Boston, MA 02111-1307, USA
 * ؼ񤤤Ƥ
 * 
-* $Id: mmenu-tab.h,v 1.50 2009/08/16 05:15:38 bowkenken Exp $
+* $Id: mmenu-tab.h,v 1.52 2009/09/13 17:48:24 bowkenken Exp $
 ***************************************************************/
 
 #ifndef	MMENU_TAB_H
@@ -958,6 +958,51 @@ menu_t	ls_menu_main[] = {
 		cb_menu_crsr_ptn, NULL,
 		FLG_NULL,
 	},
+	{
+		"/misc/config/screen/demo",
+		"<Branch>",
+		'D',
+		"",
+		N_MSG_MENU_DEMO, "",
+		cb_menu_demo, NULL,
+		FLG_NULL,
+	},
+	{
+		"/misc/config/screen/demo/cut in",
+		"<CheckItem>",
+		'C',
+		"",
+		N_MSG_MENU_SKIP_CUT_IN, "",
+		cb_menu_skip_cut_in, NULL,
+		FLG_NULL,
+	},
+	{
+		"/misc/config/screen/demo/star",
+		"<Branch>",
+		'S',
+		"",
+		N_MSG_MENU_STAR, "",
+		NULL, NULL,
+		FLG_NULL,
+	},
+	{
+		"/misc/config/screen/demo/star/cui",
+		"<OpenWinItem>",
+		'C',
+		"",
+		N_MSG_MENU_STAR_CUI, "",
+		cb_menu_star_cui, NULL,
+		FLG_NULL,
+	},
+	{
+		"/misc/config/screen/demo/star/gui",
+		"<OpenWinItem>",
+		'G',
+		"",
+		N_MSG_MENU_STAR_GUI, "",
+		cb_menu_star_gui, NULL,
+		FLG_NULL,
+	},
 /*  end */
 	{
 		"/misc/config/key",
