@@ -25,7 +25,7 @@
 *   59 Temple Place, Suite 330, Boston, MA 02111-1307, USA
 * ؼ񤤤Ƥ
 * 
-* $Id: mmenu.c,v 1.48 2009/02/01 23:45:18 bowkenken Exp $
+* $Id: mmenu.c,v 1.56 2009/07/12 08:35:36 bowkenken Exp $
 ***************************************************************/
 
 #define	MMENU_C
@@ -39,32 +39,39 @@
 
 static pos_t	g_crsr, g_pre_crsr;
 static pos_t	g_sub_crsr, g_pre_sub_crsr;
+check_memory_def( check_memory_mmenu_c_g_crsr )
 
 static menu_t	*g_menu_dflt_main;
+check_memory_def( check_memory_mmenu_c_g_menu_dflt_main )
 
 static chr_t	*g_sub_sel_mbr;
 static abl_kind_t	g_sel_abl;
 static race_t	g_sel_race;
 static sex_t	g_sel_sex;
 static long	g_sel_class_n;
+check_memory_def( check_memory_mmenu_c_g_sub_sel_mbr )
 
 static bool_t	g_flg_no_save;
 static long	g_sel_save_load_n;
+check_memory_def( check_memory_mmenu_c_g_flg_no_save )
 
 static trgt_kind_t	g_sel_obj_trgt_kind;
 static chr_kind_t	g_dist_chr_kind;
 static dist_t	g_sel_dist;
 static act_kind_t	g_sel_act_kind;
+check_memory_def( check_memory_mmenu_c_g_sel_obj_trgt_kind )
 
 static long	g_sel_mbr_n;
 static item_t	*g_sel_item;
 static equip_kind_t	g_sel_equip_kind;
 static bool_t	g_flg_equip_self;
+check_memory_def( check_memory_mmenu_c_g_sel_mbr_n )
 
 static mbr_t	*g_mark_sel_mbr;
 static item_t	*g_mark_sel_item;
 static door_t	*g_mark_sel_door;
 static trap_t	*g_mark_sel_trap;
+check_memory_def( check_memory_mmenu_c_g_mark_sel_mbr )
 
 typedef struct {
 	equip_kind_t	kind;
@@ -86,6 +93,7 @@ static ls_equip_msg_t	ls_equip_msg[] = {
 	{ EQUIP_KIND_ABOUT_BODY, N_MSG_MENU_SEL_EQUIP_ABOUT_BODY },
 	{ EQUIP_KIND_LIGHT_SOURCE, N_MSG_MENU_SEL_EQUIP_LIGHT_SOURCE },
 };
+check_memory_def( check_memory_mmenu_c_ls_equip_msg )
 
 /**/
 
@@ -94,6 +102,7 @@ static ls_equip_msg_t	ls_equip_msg[] = {
 /**/
 
 static long static_cb_menu_item__pre_sel_mbr_n;
+check_memory_def( check_memory_mmenu_c_pre_sel_mbr_n )
 
 /**/
 
@@ -167,7 +176,7 @@ char	*exec_menu_sel_mbr(
 		ls[k].accel_key = '\0';
 		ls[k].short_key[0] = '\0';
 		str_nz_cpy( ls[k].msg, ttl,
-				MENU_MSG_MAX_LEN );
+				MENU_MSG_MAX_BYTE );
 		ls[k].call_back = NULL;
 		ls[k].arg = NULL;
 		ls[k].flg = FLG_NULL;
@@ -190,7 +199,8 @@ char	*exec_menu_sel_mbr(
 				MENU_KIND_MAX_LEN );
 		ls[k].accel_key = (char)('A' + i);
 		ls[k].short_key[0] = '\0';
-		str_nz_cpy( ls[k].msg, pty->mbr[i]->name, MENU_MSG_MAX_LEN );
+		str_nz_cpy( ls[k].msg, pty->mbr[i]->name,
+				MENU_MSG_MAX_BYTE );
 		ls[k].call_back = cb_menu_sel_mbr;
 		ls[k].arg = (void *)(pty->mbr[i]);
 		ls[k].flg = FLG_NULL;
@@ -218,7 +228,7 @@ char	*exec_menu_sel_mbr(
 				MENU_KIND_MAX_LEN );
 		ls[k].accel_key = (char)('A' + MBR_MAX_N + i);
 		ls[k].short_key[0] = '\0';
-		str_nz_cpy( ls[k].msg, pet[i]->name, MENU_MSG_MAX_LEN );
+		str_nz_cpy( ls[k].msg, pet[i]->name, MENU_MSG_MAX_BYTE );
 		ls[k].call_back = cb_menu_sel_mbr;
 		ls[k].arg = (void *)(pet[i]);
 		ls[k].flg = FLG_NULL;
@@ -289,7 +299,7 @@ char	*exec_menu_sel_abl( mbr_t *mbr, abl_kind_t *abl )
 	ls[k].accel_key = '\0';
 	ls[k].short_key[0] = '\0';
 	str_nz_cpy( ls[k].msg, MSG_TTL_MENU_SEL_ABL,
-			MENU_MSG_MAX_LEN );
+			MENU_MSG_MAX_BYTE );
 	ls[k].call_back = NULL;
 	ls[k].arg = NULL;
 	ls[k].flg = FLG_NULL;
@@ -309,9 +319,9 @@ char	*exec_menu_sel_abl( mbr_t *mbr, abl_kind_t *abl )
 		ls[k].short_key[0] = '\0';
 		if( mbr == NULL ){
 			str_nz_cpy( ls[k].msg, get_abl_name( (abl_kind_t)i ),
-					MENU_MSG_MAX_LEN );
+					MENU_MSG_MAX_BYTE );
 		} else {
-			sn_printf( ls[k].msg, MENU_MSG_MAX_LEN,
+			sn_printf( ls[k].msg, MENU_MSG_MAX_BYTE,
 					"%-3s: %ld",
 					get_abl_name( (abl_kind_t)i ),
 					mbr->abl.lev[i].n );
@@ -415,7 +425,7 @@ char	*exec_menu_race( race_t *race )
 	}
 
 	str_nz_cpy( g_sel_race.name, get_race_str_main( &g_sel_race ),
-			RACE_NAME_MAX_LEN );
+			RACE_NAME_MAX_BYTE );
 
 	*race = g_sel_race;
 	return NULL;
@@ -490,7 +500,7 @@ char	*exec_menu_class( long *class_n )
 	str_nz_cpy( ls[k].kind, "<Title>", MENU_KIND_MAX_LEN );
 	ls[k].accel_key = '\0';
 	ls[k].short_key[0] = '\0';
-	str_nz_cpy( ls[k].msg, MSG_TTL_MENU_CLASS, MENU_MSG_MAX_LEN );
+	str_nz_cpy( ls[k].msg, MSG_TTL_MENU_CLASS, MENU_MSG_MAX_BYTE );
 	ls[k].call_back = NULL;
 	ls[k].arg = NULL;
 	ls[k].flg = FLG_NULL;
@@ -507,7 +517,8 @@ char	*exec_menu_class( long *class_n )
 		str_nz_cpy( ls[k].kind, "<Item>", MENU_KIND_MAX_LEN );
 		ls[k].accel_key = (char)('A' + (i % LS_CLASS_N_PER_PAGE));
 		ls[k].short_key[0] = '\0';
-		str_nz_cpy( ls[k].msg, class_tab[i].name, MENU_MSG_MAX_LEN );
+		str_nz_cpy( ls[k].msg, class_tab[i].name,
+				MENU_MSG_MAX_BYTE );
 		ls[k].call_back = cb_menu_class;
 		ls[k].arg = (void *)i;
 		ls[k].flg = FLG_NULL;
@@ -755,7 +766,7 @@ char	*cb_menu_sel_obj_init( menu_t **pp, menu_t **dflt )
 {
 	long	mjr_chr, mjr_obj;
 	flg_map_t	flg_chr, flg_obj;
-	party_t	*pty = get_party();
+	long	sq_x, sq_y;
 	dun_t	*dun = get_dun();
 
 	mjr_chr = dun->map.chr.mjr[g_crsr.y][g_crsr.x];
@@ -766,10 +777,12 @@ char	*cb_menu_sel_obj_init( menu_t **pp, menu_t **dflt )
 	clr_flg_menu( *pp, NULL, FLG_MENU_ALL );
 
 	/* С */
+
 	if( mjr_chr != FACE_MJR_MBR )
 		set_flg_menu( *pp, "member", FLG_MENU_HIDDEN );
 
 	/* 󥹥 */
+
 	if( (mjr_chr == FACE_MJR_MBR) || (mjr_chr == FACE_MJR_NULL) )
 		set_flg_menu( *pp, "monster", FLG_MENU_HIDDEN );
 	if( !chk_flg( flg_chr, FLG_MAP_CHR_FIND ) )
@@ -778,24 +791,29 @@ char	*cb_menu_sel_obj_init( menu_t **pp, menu_t **dflt )
 		set_flg_menu( *pp, "monster", FLG_MENU_HIDDEN );
 
 	/* 饹ܥ */
+
 	if( chk_xx_pos( g_crsr.x, g_crsr.y ) )
 		clr_flg_menu( *pp, "monster", FLG_MENU_HIDDEN );
 
 	/* ƥ */
+
 	if( get_item( g_crsr.x, g_crsr.y ) == NULL )
 		set_flg_menu( *pp, "item", FLG_MENU_HIDDEN );
 
 	/* ɥ */
+
 	if( (mjr_obj != FACE_MJR_DOOR_CLOSE)
 			&& (mjr_obj != FACE_MJR_DOOR_OPEN) ){
 		set_flg_menu( *pp, "door", FLG_MENU_HIDDEN );
 	}
 
 	/*  */
+
 	if( mjr_obj != FACE_MJR_TRAP )
 		set_flg_menu( *pp, "trap", FLG_MENU_HIDDEN );
 
 	/* ʤ */
+
 	if( !chk_flg( flg_obj, FLG_MAP_OBJ_FIND ) ){
 		set_flg_menu( *pp, "item", FLG_MENU_HIDDEN );
 		set_flg_menu( *pp, "door", FLG_MENU_HIDDEN );
@@ -813,12 +831,15 @@ char	*cb_menu_sel_obj_init( menu_t **pp, menu_t **dflt )
 	}
 
 	/* 󥫡 */
-	if( labs( pty->square.x - g_crsr.x ) > (SQUARE_WIDTH / 2) )
+
+	get_square_pos( &sq_x, &sq_y, FALSE );
+	if( labs( sq_x - g_crsr.x ) > (SQUARE_WIDTH / 2) )
 		set_flg_menu( *pp, "square", FLG_MENU_HIDDEN );
-	if( labs( pty->square.y - g_crsr.y ) > (SQUARE_HEIGHT / 2) )
+	if( labs( sq_y - g_crsr.y ) > (SQUARE_HEIGHT / 2) )
 		set_flg_menu( *pp, "square", FLG_MENU_HIDDEN );
 
 	/* ޡ */
+
 	if( mjr_chr != FACE_MJR_MBR )
 		set_flg_menu( *pp, "clear", FLG_MENU_HIDDEN );
 
@@ -1044,16 +1065,18 @@ bool_t	menu_mark_mnstr( pos_t pos1, pos_t pos2 )
 	mnstr = get_mnstr( pos2.x, pos2.y );
 	if( mbr == NULL )
 		return FALSE;
-	if( mnstr == NULL )
-		return FALSE;
 
 	if( !set_chr_act( mbr, g_sel_act_kind, NULL, NULL, 0, 0 ) )
 		return FALSE;
 
 	mbr->act.dflt_kind_mnstr = mbr->act.kind;
-	str_nz_cpy( mbr->act.dflt_msg_mnstr, mbr->act.msg, ACT_MSG_MAX_LEN );
+	str_nz_cpy( mbr->act.dflt_msg_mnstr, mbr->act.msg,
+			ACT_MSG_MAX_BYTE );
 
-	mark_mnstr( mbr, mnstr, g_sel_dist );
+	if( mnstr == NULL )
+		mark_mnstr_null( mbr, pos2.x, pos2.y, g_sel_dist );
+	else
+		mark_mnstr( mbr, mnstr, g_sel_dist );
 
 	draw_mbr_stat( mbr );
 
@@ -1196,7 +1219,7 @@ bool_t	menu_mark_pos( pos_t pos1, pos_t pos2 )
 	if( !set_chr_act( mbr, ACT_KIND_NULL, NULL, NULL, 0, 0 ) )
 		return FALSE;
 
-	str_nz_cpy( mbr->act.msg, MSG_TRGT_POS, ACT_MSG_MAX_LEN );
+	str_nz_cpy( mbr->act.msg, MSG_TRGT_POS, ACT_MSG_MAX_BYTE );
 	mark_pos( mbr, pos2.x, pos2.y, DIST_NEAR );
 
 	draw_mbr_stat( mbr );
@@ -1252,8 +1275,7 @@ bool_t	menu_mark_square_pos( pos_t pos )
 	sq->x = pos.x;
 	sq->y = pos.y;
 	set_square_mbr( sq );
-
-	set_mbr_dir();
+	reset_mbr_dir();
 
 	clr_msg();
 	draw_square();
@@ -1472,7 +1494,8 @@ char	*cb_menu_item( menu_t **pp, menu_t **dflt )
 		ls[k].accel_key = '\0';
 		ls[k].short_key[0] = '\0';
 		ls[k].n_msg = N_MSG_NULL;
-		str_nz_cpy( ls[k].msg, pty->mbr[i]->name, MENU_MSG_MAX_LEN );
+		str_nz_cpy( ls[k].msg, pty->mbr[i]->name,
+				MENU_MSG_MAX_BYTE );
 		ls[k].call_back = NULL;
 		ls[k].arg = NULL;
 		ls[k].flg = FLG_NULL;
@@ -1493,7 +1516,7 @@ char	*cb_menu_item( menu_t **pp, menu_t **dflt )
 				ls[k].accel_key = (char)('A' + j);
 				ls[k].short_key[0] = '\0';
 				ls[k].n_msg = N_MSG_NULL;
-				sn_printf( ls[k].msg, MENU_MSG_MAX_LEN,
+				sn_printf( ls[k].msg, MENU_MSG_MAX_BYTE,
 						" %s", p->name );
 				ls[k].call_back = cb_menu_item_sel;
 				ls[k].arg = NULL;
@@ -1510,7 +1533,7 @@ char	*cb_menu_item( menu_t **pp, menu_t **dflt )
 		ls[k].short_key[0] = '\0';
 		ls[k].n_msg = N_MSG_NULL;
 		str_nz_cpy( ls[k].msg, MSG_MENU_ITEM_LS_EQUIP,
-				MENU_MSG_MAX_LEN );
+				MENU_MSG_MAX_BYTE );
 		ls[k].call_back = cb_menu_goto_equip;
 		ls[k].arg = NULL;
 		ls[k].flg = FLG_NULL;
@@ -1826,7 +1849,7 @@ char	*cb_menu_item_smoke( menu_t **pp, menu_t **dflt )
 		mbr->act.n = EQUIP_KIND_HEAD;
 
 		str_nz_cpy( mbr->act.msg, MSG_ACT_TOBACCO_SMOKE,
-				ACT_MSG_MAX_LEN );
+				ACT_MSG_MAX_BYTE );
 	}
 
 	return ret;
@@ -2118,7 +2141,7 @@ char	*cb_menu_equip( menu_t **pp, menu_t **dflt )
 		ls[k].short_key[0] = '\0';
 		ls[k].n_msg = N_MSG_NULL;
 		str_nz_cpy( ls[k].msg,
-				pty->mbr[i]->name, MENU_MSG_MAX_LEN );
+				pty->mbr[i]->name, MENU_MSG_MAX_BYTE );
 		ls[k].call_back = NULL;
 		ls[k].arg = NULL;
 		ls[k].flg = FLG_NULL;
@@ -2146,13 +2169,13 @@ char	*cb_menu_equip( menu_t **pp, menu_t **dflt )
 			ls[k].n_msg = N_MSG_NULL;
 			if( equip[eq_k].kind == ITEM_KIND_NULL ){
 				sn_printf( ls[k].msg,
-						MENU_MSG_MAX_LEN,
+						MENU_MSG_MAX_BYTE,
 						MSG_FMT_EQUIP_NULL,
 						equip_ttl_max_len,
 						msg );
 			} else {
 				sn_printf( ls[k].msg,
-						MENU_MSG_MAX_LEN,
+						MENU_MSG_MAX_BYTE,
 						MSG_FMT_EQUIP,
 						equip_ttl_max_len,
 						msg,
@@ -2173,7 +2196,7 @@ char	*cb_menu_equip( menu_t **pp, menu_t **dflt )
 		ls[k].n_msg = N_MSG_NULL;
 		str_nz_cpy( ls[k].msg,
 				MSG_MENU_EQUIP_LS_ITEM,
-				MENU_MSG_MAX_LEN );
+				MENU_MSG_MAX_BYTE );
 		ls[k].call_back = cb_menu_goto_item;
 		ls[k].arg = NULL;
 		ls[k].flg = FLG_NULL;
@@ -2305,7 +2328,7 @@ char	*menu_equip_wear_sel( menu_t **pp, menu_t **dflt )
 		ls[k].accel_key = (char)('A' + i);
 		ls[k].short_key[0] = '\0';
 		ls[k].n_msg = N_MSG_NULL;
-		str_nz_cpy( ls[k].msg, p->name, MENU_MSG_MAX_LEN );
+		str_nz_cpy( ls[k].msg, p->name, MENU_MSG_MAX_BYTE );
 		ls[k].call_back = cb_menu_equip_wear;
 		ls[k].arg = p;
 		ls[k].flg = FLG_NULL;
@@ -2474,10 +2497,19 @@ char	*cb_menu_goto_item( menu_t **pp, menu_t **dflt )
 
 char	*cb_menu_move( menu_t **pp, menu_t **dflt )
 {
-	square_t	*sq;
-
 	set_menu_dflt_main( *pp );
 
+	menu_move_square();
+
+	return NULL;
+}
+
+/**/
+
+void	menu_move_square( void )
+{
+	square_t	*sq;
+
 	sq = get_square_mbr();
 
 	sq->pre_x = sq->x;
@@ -2528,56 +2560,66 @@ char	*cb_menu_move( menu_t **pp, menu_t **dflt )
 
 	sq->x = g_crsr.x;
 	sq->y = g_crsr.y;
-
 	set_square_mbr( sq );
+	reset_mbr_dir();
 
-	set_mbr_dir();
 	draw_square();
-
-	return NULL;
 }
 
 /**/
 
 char	*cb_menu_fight( menu_t **pp, menu_t **dflt )
 {
+	bool_t	flg_loop;
 	pos_t	pos1, pos2;
 	char	*str;
 	char	c;
 
 	set_menu_dflt_main( *pp );
 
-	pos1 = g_crsr;
-	c = get_chr_mjr_crsr();
-	if( c != FACE_MJR_MBR ){
-		mbr_t	*mbr;
+	flg_loop = FALSE;
+	do {
+		pos1 = g_crsr;
+		c = get_chr_mjr_crsr();
+		if( c != FACE_MJR_MBR ){
+			mbr_t	*mbr;
 
-		str = exec_menu_sel_mbr( &mbr, NULL, FALSE, FALSE );
-		if( str != NULL )
-			return str;
-		if( mbr == NULL )
-			return STR_MENU_ERR;
+			flg_loop = TRUE;
 
-		g_sel_mbr_n = mbr->mbr_n;
-		pos1.x = mbr->x;
-		pos1.y = mbr->y;
-	}
+			str = exec_menu_sel_mbr( &mbr, NULL, FALSE, FALSE );
+			if( str != NULL )
+				return str;
+			if( mbr == NULL )
+				return STR_MENU_ERR;
 
-	str = exec_menu_point_crsr();
-	if( str != NULL )
-		return str;
+			g_sel_mbr_n = mbr->mbr_n;
+			pos1.x = mbr->x;
+			pos1.y = mbr->y;
+		}
 
-	pos2 = g_crsr;
-	c = get_chr_mjr_crsr();
+		str = exec_menu_point_crsr();
+		if( str == NULL ){
+			flg_loop = FALSE;
+		} else {
+			if( strcmp( str, STR_MENU_CANCEL ) == 0 )
+				continue;
+			else
+				return str;
+		}
 
-	if( c == FACE_MJR_MBR ){
-		if( !menu_mark_mbr( pos1, pos2 ) )
-			return STR_MENU_ERR;
-	} else {
-		if( !menu_mark_mnstr( pos1, pos2 ) )
-			return STR_MENU_ERR;
-	}
+		pos2 = g_crsr;
+		c = get_chr_mjr_crsr();
 
+		if( c == FACE_MJR_MBR ){
+			if( !menu_mark_mbr( pos1, pos2 ) )
+				return STR_MENU_ERR;
+		} else {
+			if( !menu_mark_mnstr( pos1, pos2 ) )
+				return STR_MENU_ERR;
+		}
+	} while( flg_loop );
+
+	*pp = NULL;
 	return NULL;
 }
 
@@ -2828,18 +2870,18 @@ void	set_ttl_menu_save_load(
 	if( flg_txt ){
 		if( flg_save ){
 			str_nz_cpy( ls->msg, MSG_MENU_WIZARD_TEXT_SAVE,
-					MENU_MSG_MAX_LEN );
+					MENU_MSG_MAX_BYTE );
 		} else {
 			str_nz_cpy( ls->msg, MSG_MENU_WIZARD_TEXT_LOAD,
-					MENU_MSG_MAX_LEN );
+					MENU_MSG_MAX_BYTE );
 		}
 	} else {
 		if( flg_save ){
 			str_nz_cpy( ls->msg, MSG_MENU_BAR_SAVE,
-					MENU_MSG_MAX_LEN );
+					MENU_MSG_MAX_BYTE );
 		} else {
 			str_nz_cpy( ls->msg, MSG_MENU_BAR_LOAD,
-					MENU_MSG_MAX_LEN );
+					MENU_MSG_MAX_BYTE );
 		}
 	}
 	ls->call_back = NULL;
@@ -2936,7 +2978,8 @@ bool_t	exec_menu_identify_item( mbr_t *mbr )
 		ls[k].accel_key = '\0';
 		ls[k].short_key[0] = '\0';
 		ls[k].n_msg = N_MSG_NULL;
-		str_nz_cpy( ls[k].msg, pty->mbr[i]->name, MENU_MSG_MAX_LEN );
+		str_nz_cpy( ls[k].msg, pty->mbr[i]->name,
+				MENU_MSG_MAX_BYTE );
 		ls[k].call_back = NULL;
 		ls[k].arg = NULL;
 		ls[k].flg = FLG_NULL;
@@ -2950,16 +2993,16 @@ bool_t	exec_menu_identify_item( mbr_t *mbr )
 		j = 0;
 		if( (p == NULL) || (p == item) ){
 			sn_printf( ls[k].path, MENU_PATH_MAX_LEN,
-					"/identify item/unknown %c",
+					"/identify item/no sel %c",
 					(char)('A' + i) );
 			str_nz_cpy( ls[k].kind, "<Item>",
 					MENU_KIND_MAX_LEN );
 			ls[k].accel_key = (char)('A' + j);
 			ls[k].short_key[0] = '\0';
-			ls[k].n_msg = N_MSG_ITEM_UNKNOWN;
-			str_nz_cpy( ls[k].msg, MSG_ITEM_UNKNOWN,
-					MENU_MSG_MAX_LEN );
-			ls[k].call_back = cb_menu_identify_item_unknown;
+			ls[k].n_msg = N_MSG_ITEM_NO_SEL;
+			str_nz_cpy( ls[k].msg, MSG_ITEM_NO_SEL,
+					MENU_MSG_MAX_BYTE );
+			ls[k].call_back = cb_menu_identify_item_no_sel;
 			ls[k].arg = (void *)NULL;
 			ls[k].flg = FLG_NULL;
 			k++;
@@ -2979,7 +3022,8 @@ bool_t	exec_menu_identify_item( mbr_t *mbr )
 			ls[k].accel_key = (char)('A' + j);
 			ls[k].short_key[0] = '\0';
 			ls[k].n_msg = N_MSG_NULL;
-			str_nz_cpy( ls[k].msg, p->name, MENU_MSG_MAX_LEN );
+			str_nz_cpy( ls[k].msg, p->name,
+					MENU_MSG_MAX_BYTE );
 			ls[k].call_back = cb_menu_identify_item;
 			ls[k].arg = (void *)p;
 			ls[k].flg = FLG_NULL;
@@ -3025,7 +3069,7 @@ char	*cb_menu_identify_item( menu_t **pp, menu_t **dflt )
 
 /**/
 
-char	*cb_menu_identify_item_unknown( menu_t **pp, menu_t **dflt )
+char	*cb_menu_identify_item_no_sel( menu_t **pp, menu_t **dflt )
 {
 	return STR_MENU_CANCEL;
 }
@@ -3081,7 +3125,7 @@ bool_t	exec_menu_resurrection( mbr_t *mbr )
 	ls[k].short_key[0] = '\0';
 	ls[k].n_msg = N_MSG_NULL;
 	str_nz_cpy( ls[k].msg, MSG_TTL_MENU_RESURRECTION,
-			MENU_MSG_MAX_LEN );
+			MENU_MSG_MAX_BYTE );
 	ls[k].call_back = NULL;
 	ls[k].arg = NULL;
 	ls[k].flg = FLG_NULL;
@@ -3101,7 +3145,8 @@ bool_t	exec_menu_resurrection( mbr_t *mbr )
 		ls[k].accel_key = (char)('A' + i);
 		ls[k].short_key[0] = '\0';
 		ls[k].n_msg = N_MSG_NULL;
-		str_nz_cpy( ls[k].msg, pty->mbr[i]->name, MENU_MSG_MAX_LEN );
+		str_nz_cpy( ls[k].msg, pty->mbr[i]->name,
+				MENU_MSG_MAX_BYTE );
 		ls[k].call_back = cb_menu_resurrection;
 		ls[k].arg = pty->mbr[i];
 		ls[k].flg = FLG_NULL;
@@ -3125,7 +3170,7 @@ bool_t	exec_menu_resurrection( mbr_t *mbr )
 		ls[k].accel_key = (char)('A' + i + MBR_MAX_N);
 		ls[k].short_key[0] = '\0';
 		ls[k].n_msg = N_MSG_NULL;
-		str_nz_cpy( ls[k].msg, pet[i]->name, MENU_MSG_MAX_LEN );
+		str_nz_cpy( ls[k].msg, pet[i]->name, MENU_MSG_MAX_BYTE );
 		ls[k].call_back = cb_menu_resurrection;
 		ls[k].arg = pet[i];
 		ls[k].flg = FLG_NULL;
@@ -3202,6 +3247,9 @@ void	update_crsr( void )
 	draw_crsr();
 	draw_sub_crsr();
 
+	/* ơС˥ҥȤɽ */
+	call_gui_map_print_stat_bar_hint();
+
 	reset_crsr();
 }
 
@@ -3247,5 +3295,30 @@ void	set_sel_mbr_n( long n )
 	g_sel_mbr_n = n;
 }
 
-/**/
+/***************************************************************
+* ꡼å
+***************************************************************/
 
+void	check_memory_mmenu_c( void )
+{
+	check_memory( check_memory_mmenu_c_g_crsr,
+			"mmenu.c: g_crsr" );
+	check_memory( check_memory_mmenu_c_g_menu_dflt_main,
+			"mmenu.c: g_menu_dflt_main" );
+	check_memory( check_memory_mmenu_c_g_sub_sel_mbr,
+			"mmenu.c: g_sub_sel_mbr" );
+	check_memory( check_memory_mmenu_c_g_flg_no_save,
+			"mmenu.c: g_flg_no_save" );
+	check_memory( check_memory_mmenu_c_g_sel_obj_trgt_kind,
+			"mmenu.c: g_sel_obj_trgt_kind" );
+	check_memory( check_memory_mmenu_c_g_sel_mbr_n,
+			"mmenu.c: g_sel_mbr_n" );
+	check_memory( check_memory_mmenu_c_g_mark_sel_mbr,
+			"mmenu.c: g_mark_sel_mbr" );
+	check_memory( check_memory_mmenu_c_ls_equip_msg,
+			"mmenu.c: ls_equip_msg" );
+	check_memory( check_memory_mmenu_c_pre_sel_mbr_n,
+			"mmenu.c: pre_sel_mbr_n" );
+}
+
+/**/
