@@ -25,7 +25,7 @@
 *   59 Temple Place, Suite 330, Boston, MA 02111-1307, USA
 * ؼ񤤤Ƥ
 * 
-* $Id: party.c,v 1.239 2009/07/23 15:54:39 bowkenken Exp $
+* $Id: party.c,v 1.242 2009/09/17 22:29:53 bowkenken Exp $
 ***************************************************************/
 
 /***************************************************************
@@ -642,6 +642,11 @@ void	init_party_debug( void )
 	init_mbr_item( ls_mbr[i], ITEM_KIND_WPN, &sub_kind,
 			TRUE, FALSE, TRUE );
 
+	i = 6;
+	sub_kind.wpn = WPN_KIND_BOOMERANG;
+	init_mbr_item( ls_mbr[i], ITEM_KIND_WPN, &sub_kind,
+			TRUE, FALSE, TRUE );
+
 	/* armor */
 
 	i = 1;
@@ -736,6 +741,11 @@ void	init_party_debug( void )
 	init_mbr_item( ls_mbr[i], ITEM_KIND_SCROLL, &sub_kind,
 			TRUE, FALSE, FALSE );
 
+	i = 2;
+	sub_kind.scroll = SCROLL_KIND_BOOMERANG;
+	init_mbr_item( ls_mbr[i], ITEM_KIND_SCROLL, &sub_kind,
+			TRUE, FALSE, FALSE );
+
 	i = 4;
 	sub_kind.scroll = SCROLL_KIND_TELEPORT;
 	init_mbr_item( ls_mbr[i], ITEM_KIND_SCROLL, &sub_kind,
@@ -880,21 +890,7 @@ void	init_party_debug( void )
 	init_mbr_item( ls_mbr[i], ITEM_KIND_ARMOR, &sub_kind,
 			TRUE, FALSE, TRUE );
 
-	i = 0;
-	sub_kind.ring = RING_KIND_STRENGTH;
-	sub_kind.amulet = AMULET_KIND_NULL;
-	sub_kind.necklace = NECKLACE_KIND_NULL;
-	init_mbr_item( ls_mbr[i], ITEM_KIND_ACCE, &sub_kind,
-			TRUE, FALSE, TRUE );
-
-	i = 0;
-	sub_kind.ring = RING_KIND_NULL;
-	sub_kind.amulet = AMULET_KIND_NULL;
-	sub_kind.necklace = NECKLACE_KIND_CURSE_HEAT;
-	init_mbr_item( ls_mbr[i], ITEM_KIND_ACCE, &sub_kind,
-			FALSE, TRUE, FALSE );
-
-	i = 0;
+	i = 1;
 	sub_kind.ring = RING_KIND_DRAIN_HP;
 	sub_kind.amulet = AMULET_KIND_NULL;
 	sub_kind.necklace = NECKLACE_KIND_NULL;
