@@ -18,6 +18,7 @@ void	appear_all_pet( void );
 void	appear_pet( pet_t *p );
 void	move_phase_all_pet( void );
 void	act_phase_all_pet( void );
+void	dismissal_phase_all_pet( void );
 void	set_act_pet_std( pet_t *p );
 void	pet_mark_std( pet_t *p );
 void	chk_trap_all_pet( void );
@@ -35,6 +36,8 @@ void	garbage_collection_all_pet( void );
 void	die_pet( pet_t *p, bool_t flg_msg );
 void	remove_pet( pet_t *p );
 bool_t	dismissal( pet_t *p );
+long	calc_pet_n( void );
+void	check_memory_pet_c( void );
 
 #ifdef __cplusplus
 }
