@@ -25,7 +25,7 @@
 *   59 Temple Place, Suite 330, Boston, MA 02111-1307, USA
 * ؼ񤤤Ƥ
 * 
-* $Id: pet.c,v 1.63 2009/03/10 09:06:46 bowkenken Exp $
+* $Id: pet.c,v 1.70 2009/07/23 12:52:01 bowkenken Exp $
 ***************************************************************/
 
 /***************************************************************
@@ -39,12 +39,15 @@
 
 /* ѡƥΤĤƤڥåȤΥꥹ */
 static pet_t	*party_pet[PET_MAX_N];
+check_memory_def( check_memory_pet_c_party_pet )
 
 /* ƤΥڥåȤΥꥹ */
 static pet_t	*ls_pet[LS_PET_MAX_N + 1];
+check_memory_def( check_memory_pet_c_ls_pet )
 
 /* ڥåȤΥ꡼ס */
 static pet_t	ls_pet_buf[LS_PET_MAX_N + 1];
+check_memory_def( check_memory_pet_c_ls_pet_buf )
 
 /***************************************************************
 * ڥåȤν
@@ -94,7 +97,7 @@ void	init_pet_dflt( void )
 	if( p == NULL )
 		return;
 
-	str_nz_cpy( p->name, "Pyon Pyon", PET_NAME_MAX_LEN );
+	str_nz_cpy( p->name, "Pyon Pyon", PET_NAME_MAX_BYTE );
 	join_pet( p );
 }
 
@@ -113,7 +116,7 @@ void	init_pet_debug( void )
 	if( p == NULL )
 		return;
 
-	str_nz_cpy( p->name, "Pyon Pyon", PET_NAME_MAX_LEN );
+	str_nz_cpy( p->name, "Pyon Pyon", PET_NAME_MAX_BYTE );
 	join_pet( p );
 }
 
@@ -334,6 +337,25 @@ void	act_phase_all_pet( void )
 	}
 }
 
+/***************************************************************
+* ƤΥڥåȤԥե¹
+***************************************************************/
+
+void	dismissal_phase_all_pet( void )
+{
+	long	i;
+
+	for( i = 0; i < PET_MAX_N; i++ ){
+		pet_t	*pp;
+
+		pp = party_pet[i];
+		if( pp == NULL )
+			continue;
+
+		dismissal_phase_chr( pp );
+	}
+}
+
 /***************************************************************
 * ڥåȤɸŪʹư
 * pet_t *p : ڥå
@@ -556,16 +578,17 @@ void	chk_pet_owner( pet_t *p )
 	if( p == NULL )
 		return;
 
-	if( p->owner == NULL )
-		clr_pet_owner( p );
-
-	if( (p->owner != NULL) && chk_flg_or( p->owner->stat,
-			FLG_STAT_NOT_EXIST | FLG_STAT_DEAD ) ){
+	if( p->owner == NULL ){
 		clr_pet_owner( p );
+	} else {
+		if( chk_flg_or( p->owner->stat,
+				FLG_STAT_NOT_EXIST | FLG_STAT_DEAD ) ){
+			clr_pet_owner( p );
+		}
+		if( p->owner->mbr_n == MBR_N_NOT_JOIN ){
+			clr_pet_owner( p );
+		}
 	}
-
-	if( (p->owner != NULL) && (p->owner->mbr_n == MBR_N_NOT_JOIN) )
-		clr_pet_owner( p );
 }
 
 /***************************************************************
@@ -692,10 +715,16 @@ void	garbage_collection_all_pet( void )
 /***************************************************************
 * ڥåȤν
 * pet_t *p : ڥå
+* bool_t flg_msg : åɸ뤫?
 ***************************************************************/
 
-void	die_pet( pet_t *p )
+void	die_pet( pet_t *p, bool_t flg_msg )
 {
+	if( p == NULL )
+		return;
+
+	if( flg_msg )
+		call_game_sound_play( SOUND_KIND_FIGHT_DIE_MEMBER, 1 );
 }
 
 /***************************************************************
@@ -742,3 +771,40 @@ bool_t	dismissal( pet_t *p )
 
 	return TRUE;
 }
+
+/***************************************************************
+* ѡƥΥڥåȤο
+* return : ڥåȤο
+***************************************************************/
+
+long	calc_pet_n( void )
+{
+	long	n;
+	long	i;
+
+	n = 0;
+	for( i = 0; i < PET_MAX_N; i++ ){
+		if( party_pet[i] == NULL )
+			continue;
+		if( chk_flg( party_pet[i]->stat, FLG_STAT_NOT_EXIST ) )
+			continue;
+
+		n++;
+	}
+
+	return n;
+}
+
+/***************************************************************
+* ꡼å
+***************************************************************/
+
+void	check_memory_pet_c( void )
+{
+	check_memory( check_memory_pet_c_party_pet,
+			"pet.c: party_pet" );
+	check_memory( check_memory_pet_c_ls_pet,
+			"pet.c: ls_pet" );
+	check_memory( check_memory_pet_c_ls_pet_buf,
+			"pet.c: ls_pet_buf" );
+}
