@@ -1,6 +1,6 @@
 /***************************************************************
 * L&L - Labyrinths & Legends
-* Copyright (c) 1993-2008 YOSHIMURA Tomohiko All rights reserved.
+* Copyright (c) 1993-2009 YOSHIMURA Tomohiko All rights reserved.
 * 
 * Created by BowKenKen
 *   URL: https://sourceforge.jp/projects/lnl/
@@ -25,7 +25,7 @@
 *   59 Temple Place, Suite 330, Boston, MA 02111-1307, USA
 * ؼ񤤤Ƥ
 * 
-* $Id: replay.c,v 1.16 2008/04/16 16:12:34 bowkenken Exp $
+* $Id: replay.c,v 1.22 2009/08/15 04:45:56 bowkenken Exp $
 ***************************************************************/
 
 /***************************************************************
@@ -38,20 +38,28 @@
 /***************************************************************/
 
 static long	g_replay_save_slot;
+check_memory_def( check_memory_replay_c_g_replay_save_slot )
 
 static bool_t	g_flg_reg_replay[REPLAY_SLOT_MAX_N];
+check_memory_def( check_memory_replay_c_g_flg_reg_replay )
 static long	g_replay_randm_seed[REPLAY_SLOT_MAX_N];
+check_memory_def( check_memory_replay_c_g_replay_randm_seed )
 static replay_t	*g_replay_head[REPLAY_SLOT_MAX_N];
+check_memory_def( check_memory_replay_c_g_replay_head )
 static replay_t	*g_replay_cur[REPLAY_SLOT_MAX_N];
+check_memory_def( check_memory_replay_c_g_replay_cur )
 static replay_t	*g_replay_cur_draw;
+check_memory_def( check_memory_replay_c_g_replay_cur_draw )
 
 static bool_t	g_flg_play_replay;
 static long	g_play_replay_turn;
 static long	g_play_replay_count;
 static long	g_play_replay_char;
+check_memory_def( check_memory_replay_c_g_flg_play_replay )
 
 static long	g_play_replay_idx;
 static long	g_play_replay_idx_draw;
+check_memory_def( check_memory_replay_c_g_play_replay_idx )
 
 /***************************************************************
 * ץ쥤
@@ -293,6 +301,9 @@ bool_t	set_replay_char_slot(
 	if( !ready_replay( sn, FALSE ) )
 		return FALSE;
 
+	if( (KEY_N_0 <= c) && (c <= KEY_N_MAX) )
+		return TRUE;
+
 	if( kind != g_replay_cur[sn]->kind ){
 		if( !ready_replay( sn, TRUE ) )
 			return FALSE;
@@ -436,6 +447,39 @@ bool_t	get_draw_replay( char *buf, long *idx, long *len )
 	return flg_redraw;
 }
 
+/***************************************************************
+* ץ쥤ѥǡ֤ (GUI )
+* char *buf : ꥹȤ֤
+* long len : Ĺ
+***************************************************************/
+
+void	get_draw_replay_gui( char *buf, long len )
+{
+	replay_t	*p;
+	long	idx;
+	long	i;
+
+	if( buf == NULL )
+		return;
+
+	buf[0] = '\0';
+	p = g_replay_cur[REPLAY_SLOT_PLAY];
+	if( p == NULL )
+		return;
+	idx = g_play_replay_idx;
+
+	for( i = 0; i < len; i++ ){
+		char	tmp[1 + 1];
+
+		tmp[0] = get_replay_next_key( &p, &idx );
+		tmp[1] = '\0';
+		if( tmp[0] == '\0' )
+			break;
+
+		str_max_n_cat( buf, cv_esc_ctrl_str( tmp ), len );
+	}
+}
+
 /***************************************************************
 * ץ쥤Υå
 * g_play_replay_turn, g_play_replay_count, g_play_replay_char
@@ -518,6 +562,8 @@ long	get_replay_key( void )
 
 /***************************************************************
 * Υץ쥤֤
+* replay_t **pp : 
+* long *idx : ߤΥΰ֤֤
 * return : ץ쥤
 ***************************************************************/
 
@@ -577,9 +623,17 @@ void	set_flg_play_replay( bool_t flg )
 
 		g_play_replay_idx = 0;
 		g_play_replay_idx_draw = 0;
+
+		if( g_flg_gui )
+			call_gui_replay_bgn();
 	} else {
 		g_play_replay_turn = -1;
 		g_play_replay_count = 0;
+
+		redraw_all();
+
+		if( g_flg_gui )
+			call_gui_replay_end();
 	}
 }
 
@@ -694,3 +748,27 @@ void	free_replay( replay_t *p )
 {
 	free_mem( p );
 }
+
+/***************************************************************
+* ꡼å
+***************************************************************/
+
+void	check_memory_replay_c( void )
+{
+	check_memory( check_memory_replay_c_g_replay_save_slot,
+			"replay.c: g_replay_save_slot" );
+	check_memory( check_memory_replay_c_g_flg_reg_replay,
+			"replay.c: g_flg_reg_replay" );
+	check_memory( check_memory_replay_c_g_replay_randm_seed,
+			"replay.c: g_replay_randm_seed" );
+	check_memory( check_memory_replay_c_g_replay_head,
+			"replay.c: g_replay_head" );
+	check_memory( check_memory_replay_c_g_replay_cur,
+			"replay.c: g_replay_cur" );
+	check_memory( check_memory_replay_c_g_replay_cur_draw,
+			"replay.c: g_replay_cur_draw" );
+	check_memory( check_memory_replay_c_g_flg_play_replay,
+			"replay.c: g_flg_play_replay" );
+	check_memory( check_memory_replay_c_g_play_replay_idx,
+			"replay.c: g_play_replay_idx" );
+}
