@@ -25,7 +25,7 @@
 *   59 Temple Place, Suite 330, Boston, MA 02111-1307, USA
 * ؼ񤤤Ƥ
 * 
-* $Id: request.c,v 1.108 2009/05/24 07:29:25 bowkenken Exp $
+* $Id: request.c,v 1.114 2009/07/13 06:38:33 bowkenken Exp $
 ***************************************************************/
 
 /***************************************************************
@@ -125,15 +125,20 @@ scroll_kind_t	ls_reward_scroll[] = {
 
 	SCROLL_KIND_NULL,
 };
+check_memory_def( check_memory_request_c_ls_reward_scroll )
 
 /***************************************************************
 * Хѿ
 ***************************************************************/
 
 /* Υǡꥹ */
+check_memory_def( check_memory_request_c_g_request_pre )
 static request_t	g_request[REQUEST_MAX_N];
+check_memory_def( check_memory_request_c_g_request )
+
 /* Υ˥塼 */
 static menu_t	ls_menu_request[1 + REQUEST_MAX_N * 2];
+check_memory_def( check_memory_request_c_ls_menu_request )
 
 /***************************************************************
 * Υơ֥
@@ -247,8 +252,6 @@ request_t	*make_request_rare_goods( request_t *req )
 	if( req == NULL )
 		return NULL;
 
-	req->kind = REQUEST_KIND_RARE_GOODS;
-
 	dun_max_lev = get_request_dun_max_lev_easy();
 	dun_lev = REQUEST_DUN_MIN_LEV_EASY;
 	dun_lev += randm( dun_max_lev - REQUEST_DUN_MIN_LEV_EASY );
@@ -279,10 +282,14 @@ request_t	*make_request_rare_goods( request_t *req )
 
 	req->prize = calc_mnstr_gold( labs( req->dun_max_lev ),
 			REQUEST_RARE_GOODS_GOLD_RATE );
-	req->exp = calc_mnstr_exp( NULL, labs( req->dun_max_lev ) );
+	req->exp = calc_mnstr_exp( req->mnstr_kind,
+			labs( req->dun_max_lev ) );
 	req->exp *= REQUEST_RARE_GOODS_EXP_RATE;
 	req->exp /= _100_PERCENT;
 
+	/**/
+	req->kind = REQUEST_KIND_RARE_GOODS;
+
 	req->idx_fmt = get_ls_n_msg_idx_randm( g_rare_goods_tab );
 	set_request_msg( req );
 	set_request_heading( req );
@@ -305,8 +312,6 @@ request_t	*make_request_tame_mnstr( request_t *req )
 	if( req == NULL )
 		return NULL;
 
-	req->kind = REQUEST_KIND_TAME_MNSTR;
-
 	dun_max_lev = get_request_dun_max_lev_easy();
 	set_request_dun_lev( req,
 			REQUEST_DUN_MIN_LEV_EASY,
@@ -334,10 +339,14 @@ request_t	*make_request_tame_mnstr( request_t *req )
 
 	req->prize = calc_mnstr_gold( labs( req->dun_max_lev ),
 			REQUEST_TAME_MNSTR_GOLD_RATE );
-	req->exp = calc_mnstr_exp( NULL, labs( req->dun_max_lev ) );
+	req->exp = calc_mnstr_exp( MNSTR_KIND_NULL,
+			labs( req->dun_max_lev ) );
 	req->exp *= REQUEST_TAME_MNSTR_EXP_RATE;
 	req->exp /= _100_PERCENT;
 
+	/**/
+	req->kind = REQUEST_KIND_TAME_MNSTR;
+
 	req->idx_fmt = get_ls_n_msg_idx_randm( g_tame_mnstr_tab );
 	set_request_msg( req );
 	set_request_heading( req );
@@ -359,8 +368,6 @@ request_t	*make_request_rescue( request_t *req )
 	if( req == NULL )
 		return NULL;
 
-	req->kind = REQUEST_KIND_RESCUE;
-
 	dun_max_lev = get_request_dun_max_lev_normal();
 	set_request_dun_lev( req,
 			REQUEST_DUN_MIN_LEV_NORMAL,
@@ -384,10 +391,14 @@ request_t	*make_request_rescue( request_t *req )
 
 	req->prize = calc_mnstr_gold( labs( req->dun_max_lev ),
 			REQUEST_RESCUE_GOLD_RATE );
-	req->exp = calc_mnstr_exp( NULL, labs( req->dun_max_lev ) );
+	req->exp = calc_mnstr_exp( MNSTR_KIND_NULL,
+			labs( req->dun_max_lev ) );
 	req->exp *= REQUEST_RESCUE_EXP_RATE;
 	req->exp /= _100_PERCENT;
 
+	/**/
+	req->kind = REQUEST_KIND_RESCUE;
+
 	req->idx_fmt = get_ls_n_msg_idx_randm( g_rescue_tab );
 	set_request_msg( req );
 	set_request_heading( req );
@@ -412,8 +423,6 @@ request_t	*make_request_tour_guide( request_t *req )
 	if( req == NULL )
 		return NULL;
 
-	req->kind = REQUEST_KIND_TOUR_GUIDE;
-
 	dun_max_lev = get_request_dun_max_lev_easy();
 	dun_lev = REQUEST_DUN_MIN_LEV_EASY;
 	dun_lev += randm( dun_max_lev - REQUEST_DUN_MIN_LEV_EASY );
@@ -447,10 +456,14 @@ request_t	*make_request_tour_guide( request_t *req )
 
 	req->prize = calc_mnstr_gold( labs( req->dun_max_lev ),
 			REQUEST_TOUR_GUIDE_GOLD_RATE );
-	req->exp = calc_mnstr_exp( NULL, labs( req->dun_max_lev ) );
+	req->exp = calc_mnstr_exp( req->mnstr_kind,
+			labs( req->dun_max_lev ) );
 	req->exp *= REQUEST_TOUR_GUIDE_EXP_RATE;
 	req->exp /= _100_PERCENT;
 
+	/**/
+	req->kind = REQUEST_KIND_TOUR_GUIDE;
+
 	req->idx_fmt = get_ls_n_msg_idx_randm( g_tour_guide_tab );
 	set_request_msg( req );
 	set_request_heading( req );
@@ -475,8 +488,6 @@ request_t	*make_request_exterminate( request_t *req )
 	if( req == NULL )
 		return NULL;
 
-	req->kind = REQUEST_KIND_EXTERMINATE;
-
 	dun_max_lev = get_request_dun_max_lev_normal();
 	dun_lev = REQUEST_DUN_MIN_LEV_NORMAL;
 	dun_lev += randm( dun_max_lev - REQUEST_DUN_MIN_LEV_NORMAL );
@@ -512,10 +523,14 @@ request_t	*make_request_exterminate( request_t *req )
 
 	req->prize = calc_mnstr_gold( labs( req->dun_max_lev ),
 			REQUEST_EXTERMINATE_GOLD_RATE );
-	req->exp = calc_mnstr_exp( NULL, labs( req->dun_max_lev ) );
+	req->exp = calc_mnstr_exp( req->mnstr_kind,
+			labs( req->dun_max_lev ) );
 	req->exp *= REQUEST_EXTERMINATE_EXP_RATE;
 	req->exp /= _100_PERCENT;
 
+	/**/
+	req->kind = REQUEST_KIND_EXTERMINATE;
+
 	req->idx_fmt = get_ls_n_msg_idx_randm( g_exterminate_tab );
 	set_request_msg( req );
 	set_request_heading( req );
@@ -537,8 +552,6 @@ request_t	*make_request_revenge( request_t *req )
 	if( req == NULL )
 		return NULL;
 
-	req->kind = REQUEST_KIND_REVENGE;
-
 	dun_max_lev = get_request_dun_max_lev_normal();
 	set_request_dun_lev( req,
 			REQUEST_DUN_MIN_LEV_NORMAL,
@@ -567,10 +580,14 @@ request_t	*make_request_revenge( request_t *req )
 
 	req->prize = calc_mnstr_gold( labs( req->dun_max_lev ),
 			REQUEST_REVENGE_GOLD_RATE );
-	req->exp = calc_mnstr_exp( NULL, labs( req->dun_max_lev ) );
+	req->exp = calc_mnstr_exp( req->mnstr_kind,
+			labs( req->dun_max_lev ) );
 	req->exp *= REQUEST_REVENGE_EXP_RATE;
 	req->exp /= _100_PERCENT;
 
+	/**/
+	req->kind = REQUEST_KIND_REVENGE;
+
 	req->idx_fmt = get_ls_n_msg_idx_randm( g_revenge_tab );
 	set_request_msg( req );
 	set_request_heading( req );
@@ -592,8 +609,6 @@ request_t	*make_request_wanted_criminal( request_t *req )
 	if( req == NULL )
 		return NULL;
 
-	req->kind = REQUEST_KIND_WANTED_CRIMINAL;
-
 	dun_max_lev = get_request_dun_max_lev_normal();
 	set_request_dun_lev( req,
 			REQUEST_DUN_MIN_LEV_NORMAL,
@@ -622,10 +637,14 @@ request_t	*make_request_wanted_criminal( request_t *req )
 
 	req->prize = calc_mnstr_gold( labs( req->dun_max_lev ),
 			REQUEST_WANTED_CRIMINAL_GOLD_RATE );
-	req->exp = calc_mnstr_exp( NULL, labs( req->dun_max_lev ) );
+	req->exp = calc_mnstr_exp( req->mnstr_kind,
+			labs( req->dun_max_lev ) );
 	req->exp *= REQUEST_WANTED_CRIMINAL_EXP_RATE;
 	req->exp /= _100_PERCENT;
 
+	/**/
+	req->kind = REQUEST_KIND_WANTED_CRIMINAL;
+
 	req->idx_fmt = get_ls_n_msg_idx_randm( g_wanted_criminal_tab );
 	set_request_msg( req );
 	set_request_heading( req );
@@ -661,6 +680,12 @@ bool_t	make_client( request_t *req, mnstr_kind_t kind, bool_t flg_now )
 	if( owner == NULL )
 		return FALSE;
 
+	if( calc_pet_n() >= PET_MAX_N ){
+		print_msg( FLG_MSG_ERR,
+				MSG_ERR_MENU_REQUEST_CAN_NOT_JOIN_PET );
+		return FALSE;
+	}
+
 	name = MSG_MNSTR_UNKNOWN;
 	sex = FEMALE;
 	npc_dun_lev = 1;
@@ -734,7 +759,7 @@ bool_t	make_client( request_t *req, mnstr_kind_t kind, bool_t flg_now )
 	if( npc == NULL )
 		return FALSE;
 
-	str_nz_cpy( npc->name, name, CHR_NAME_MAX_LEN );
+	str_nz_cpy( npc->name, name, CHR_NAME_MAX_BYTE );
 	npc->sex.org = sex;
 	npc->sex.cur = sex;
 	npc->work.request = req;
@@ -743,6 +768,8 @@ bool_t	make_client( request_t *req, mnstr_kind_t kind, bool_t flg_now )
 		npc->flg_chr |= FLG_CHR_NO_MARK_MNSTR;
 
 	if( !join_pet( npc ) ){
+		print_msg( FLG_MSG_ERR,
+				MSG_ERR_MENU_REQUEST_CAN_NOT_JOIN_PET );
 		die_chr( npc, FALSE, FALSE, TRUE );
 		return FALSE;
 	}
@@ -1157,7 +1184,8 @@ bool_t	chk_request_limit_client( request_t *req )
 			mnstr = NULL;
 		}
 		if( mnstr != NULL ){
-			str_nz_cpy( mnstr->name, npc->name, CHR_NAME_MAX_LEN );
+			str_nz_cpy( mnstr->name, npc->name,
+					CHR_NAME_MAX_BYTE );
 			mnstr->sex.org = npc->sex.cur;
 			mnstr->sex.cur = mnstr->sex.org;
 		}
@@ -1242,8 +1270,8 @@ void	chk_set_request_npc_contract( void )
 
 bool_t	set_request_msg( request_t *req )
 {
-	static char	buf[REQUEST_MSG_MAX_LEN + 1];
-	static char	str_contract[REQUEST_MSG_MAX_LEN + 1];
+	static char	buf[REQUEST_MSG_MAX_BYTE + 1];
+	static char	str_contract[REQUEST_MSG_MAX_BYTE + 1];
 	char	*fmt;
 	long	buf_idx, fmt_idx;
 
@@ -1253,7 +1281,7 @@ bool_t	set_request_msg( request_t *req )
 	fmt = cv_idx_to_request_fmt( req );
 
 	buf[0] = '\0';
-	for( buf_idx = 0, fmt_idx = 0; buf_idx < REQUEST_MSG_MAX_LEN - 2;
+	for( buf_idx = 0, fmt_idx = 0; buf_idx < REQUEST_MSG_MAX_BYTE - 2;
 			buf_idx++, fmt_idx++ ){
 		if( fmt[fmt_idx] == '\0' ){
 			break;
@@ -1287,17 +1315,17 @@ bool_t	set_request_msg( request_t *req )
 		else
 			name = cv_idx_to_contract_name( req );
 
-		sn_printf( str_contract, REQUEST_MSG_MAX_LEN,
+		sn_printf( str_contract, REQUEST_MSG_MAX_BYTE,
 				MSG_REQUEST_CONTRACT_FMT, name );
 	} else {
 		str_nz_cpy( str_contract,
 				MSG_REQUEST_DO_NOT_CONTRACT,
-				REQUEST_MSG_MAX_LEN );
+				REQUEST_MSG_MAX_BYTE );
 	}
-	str_max_n_cat( buf, "\n", REQUEST_MSG_MAX_LEN );
-	str_max_n_cat( buf, str_contract, REQUEST_MSG_MAX_LEN );
+	str_max_n_cat( buf, "\n", REQUEST_MSG_MAX_BYTE );
+	str_max_n_cat( buf, str_contract, REQUEST_MSG_MAX_BYTE );
 
-	str_nz_cpy( req->msg, buf, REQUEST_MSG_MAX_LEN );
+	str_nz_cpy( req->msg, buf, REQUEST_MSG_MAX_BYTE );
 
 	return TRUE;
 }
@@ -1383,7 +1411,7 @@ void	set_request_msg_var_dun_min_lev(
 	if( req == NULL )
 		return;
 
-	sn_printf( buf, REQUEST_MSG_MAX_LEN, "%ld", req->dun_min_lev );
+	sn_printf( buf, REQUEST_MSG_MAX_BYTE, "%ld", req->dun_min_lev );
 }
 
 /***************************************************************
@@ -1403,7 +1431,7 @@ void	set_request_msg_var_dun_max_lev(
 	if( req == NULL )
 		return;
 
-	sn_printf( buf, REQUEST_MSG_MAX_LEN, "%ld", req->dun_max_lev );
+	sn_printf( buf, REQUEST_MSG_MAX_BYTE, "%ld", req->dun_max_lev );
 }
 
 /***************************************************************
@@ -1509,7 +1537,7 @@ void	set_request_msg_var_rare_goods(
 	if( tab == NULL )
 		return;
 
-	sn_printf( buf, REQUEST_MSG_MAX_LEN,
+	sn_printf( buf, REQUEST_MSG_MAX_BYTE,
 			MSG_REQUEST_VAR_QUOTE, tab->name );
 }
 
@@ -1545,11 +1573,11 @@ void	set_request_msg_var_mnstr(
 
 		tab = get_mnstr_tab( req->mnstr_kind, req->dun_true_lev );
 		if( tab == NULL ){
-			sn_printf( buf, REQUEST_MSG_MAX_LEN,
+			sn_printf( buf, REQUEST_MSG_MAX_BYTE,
 					MSG_REQUEST_VAR_QUOTE,
 					MSG_MNSTR_UNKNOWN );
 		} else {
-			sn_printf( buf, REQUEST_MSG_MAX_LEN,
+			sn_printf( buf, REQUEST_MSG_MAX_BYTE,
 					MSG_REQUEST_VAR_QUOTE,
 					tab->name );
 		}
@@ -1573,7 +1601,7 @@ void	set_request_msg_var_mnstr_n(
 	if( req == NULL )
 		return;
 
-	sn_printf( buf, REQUEST_MSG_MAX_LEN,
+	sn_printf( buf, REQUEST_MSG_MAX_BYTE,
 			MSG_REQUEST_MNSTR_N, req->mnstr_n );
 }
 
@@ -1792,11 +1820,11 @@ void	set_request_msg_var_ls(
 		*n_msg_idx = get_ls_n_msg_idx_randm( ls_msg );
 
 	if( flg_quote ){
-		sn_printf( buf, REQUEST_MSG_MAX_LEN,
+		sn_printf( buf, REQUEST_MSG_MAX_BYTE,
 				MSG_REQUEST_VAR_QUOTE,
 				MSG( ls_msg[*n_msg_idx] ) );
 	} else {
-		sn_printf( buf, REQUEST_MSG_MAX_LEN,
+		sn_printf( buf, REQUEST_MSG_MAX_BYTE,
 				MSG_S,
 				MSG( ls_msg[*n_msg_idx] ) );
 	}
@@ -1832,7 +1860,7 @@ bool_t	set_request_heading( request_t *req )
 	name = get_request_kind_name( req->kind );
 	len = get_pading_len( name, REQUEST_NAME_MIN_LEN );
 
-	sn_printf( req->heading, MENU_MSG_MAX_LEN,
+	sn_printf( req->heading, MENU_MSG_MAX_BYTE,
 			MSG_REQUEST_HEADING_FMT,
 			str_contract,
 			len,
@@ -1869,12 +1897,12 @@ bool_t	chr_contract_request(
 	/**/
 
 	if( kind == CHR_KIND_MBR ){
+		if( !make_client( req, get_npc_kind_randm(), FALSE ) )
+			return FALSE;
+
 		req->idx_contract_name = -1;
 		req->contract_sex = FEMALE;
 		req->flg_contract_mbr = TRUE;
-
-		if( !make_client( req, get_npc_kind_randm(), FALSE ) )
-			return FALSE;
 	} else if( kind == CHR_KIND_MNSTR ){
 		req->idx_contract_name = n_idx_name;
 		req->contract_sex = sex;
@@ -1989,6 +2017,8 @@ bool_t	finish_request( request_t *req )
 	if( req->flg_finish )
 		return FALSE;
 
+	call_game_sound_play( SOUND_KIND_REQUEST_FINISH, 1 );
+
 	req->flg_finish = TRUE;
 
 	curs_attrset_chr( pty->mbr[0], +1, TRUE );
@@ -2132,7 +2162,9 @@ bool_t	chk_finish_request_join( request_t *req, mnstr_t *npc )
 		return FALSE;
 	}
 
-	make_client( npc->work.request, npc->mnstr_kind, TRUE );
+	if( !make_client( npc->work.request, npc->mnstr_kind, TRUE ) )
+		return FALSE;
+
 	die_chr( npc, FALSE, FALSE, TRUE );
 	finish_request( req );
 
@@ -2616,7 +2648,7 @@ void	put_request_mnstr( void )
 		} else {
 			p->attitude = ATTITUDE_ENEMY;
 		}
-		str_nz_cpy( p->name, name, CHR_NAME_MAX_LEN );
+		str_nz_cpy( p->name, name, CHR_NAME_MAX_BYTE );
 		p->work.request = &(g_request[i]);
 		p->sex.org = sex;
 		p->sex.cur = sex;
@@ -2706,7 +2738,7 @@ char	*set_menu_request(
 	ls[k].accel_key = '\0';
 	ls[k].short_key[0] = '\0';
 	ls[k].n_msg = N_MSG_NULL;
-	str_nz_cpy( ls[k].msg, MSG_MENU_BAR_REQUEST, MENU_MSG_MAX_LEN );
+	str_nz_cpy( ls[k].msg, MSG_MENU_BAR_REQUEST, MENU_MSG_MAX_BYTE );
 	ls[k].call_back = NULL;
 	ls[k].arg = NULL;
 	ls[k].flg = FLG_NULL;
@@ -2714,7 +2746,9 @@ char	*set_menu_request(
 
 	n = 0;
 	for( i = 0; i < REQUEST_MAX_N; i++ ){
-		if( g_request[i].kind == REQUEST_KIND_NULL )
+		if( g_request[i].kind <= REQUEST_KIND_NULL )
+			continue;
+		if( g_request[i].kind >= REQUEST_KIND_MAX_N )
 			continue;
 
 		/* СƤʳåפ */
@@ -2732,7 +2766,7 @@ char	*set_menu_request(
 		ls[k].short_key[0] = '\0';
 		ls[k].n_msg = N_MSG_NULL;
 		str_nz_cpy( ls[k].msg, g_request[i].heading,
-				MENU_MSG_MAX_LEN );
+				MENU_MSG_MAX_BYTE );
 		ls[k].call_back = cb;
 		ls[k].arg = &(g_request[i]);
 		ls[k].flg = FLG_NULL;
@@ -2747,7 +2781,7 @@ char	*set_menu_request(
 			ls[k].accel_key = 'Z';
 			ls[k].short_key[0] = '\0';
 			ls[k].n_msg = N_MSG_NULL;
-			sn_printf( ls[k].msg, MENU_MSG_MAX_LEN,
+			sn_printf( ls[k].msg, MENU_MSG_MAX_BYTE,
 					MSG_MENU_REQUEST_REFRESH,
 					fmt_gold( REQUEST_REFRESH_PRIZE ) );
 			ls[k].call_back = cb_menu_request_refresh;
@@ -2778,7 +2812,7 @@ char	*set_menu_request(
 		ls[k].accel_key = 'Z';
 		ls[k].short_key[0] = '\0';
 		ls[k].n_msg = N_MSG_NULL;
-		sn_printf( ls[k].msg, MENU_MSG_MAX_LEN,
+		sn_printf( ls[k].msg, MENU_MSG_MAX_BYTE,
 				MSG_MENU_REQUEST_REFRESH,
 				fmt_gold( REQUEST_REFRESH_PRIZE ) );
 		ls[k].call_back = cb_menu_request_refresh;
@@ -2882,8 +2916,10 @@ char	*cb_menu_request_refresh( menu_t **pp, menu_t **dflt )
 			continue;
 
 		/* СƤϥåפ */
-		if( g_request[i].flg_contract_mbr )
+		if( g_request[i].flg_contract
+				&& g_request[i].flg_contract_mbr ){
 			continue;
+		}
 
 		free_request( &(g_request[i]) );
 	}
@@ -2918,13 +2954,16 @@ bool_t	ask_contract_request( request_t *req )
 	if( ask != ASK_YES )
 		return FALSE;
 
+	if( !chr_contract_request( req, CHR_KIND_MBR, -1, FEMALE ) )
+		return FALSE;
+
 	master_sex = get_npc_sex_shop( SHOP_N_BAR );
 	master_name = get_npc_name_shop( SHOP_N_BAR, master_sex );
 	print_words_win( master_name, master_sex,
 			MSG_WORDS_REQUEST_CONTRACT_FEMALE,
 			MSG_WORDS_REQUEST_CONTRACT_MALE );
 
-	return( chr_contract_request( req, CHR_KIND_MBR, -1, FEMALE ) );
+	return TRUE;
 }
 
 /***************************************************************
@@ -2935,7 +2974,7 @@ bool_t	ask_contract_request( request_t *req )
 
 bool_t	ask_cancel_request( request_t *req )
 {
-	char	msg[MENU_MSG_MAX_LEN + 1];
+	char	msg[MENU_MSG_MAX_BYTE + 1];
 	gold_t	penalty;
 	ask_t	ask;
 	sex_t	master_sex;
@@ -2946,7 +2985,7 @@ bool_t	ask_cancel_request( request_t *req )
 
 	penalty = req->prize * REQUEST_PENALTY_RATE / _100_PERCENT;
 
-	sn_printf( msg, MENU_MSG_MAX_LEN,
+	sn_printf( msg, MENU_MSG_MAX_BYTE,
 			MSG_TTL_MENU_REQUEST_MBR_CANCEL,
 			fmt_gold( penalty ) );
 	ask = exec_menu_ask( msg, ASK_NO, TRUE );
@@ -3153,3 +3192,18 @@ char	*cv_idx_to_client_mate_name( request_t *req )
 	return( MSG( n_msg ) );
 }
 
+/***************************************************************
+* ꡼å
+***************************************************************/
+
+void	check_memory_request_c( void )
+{
+	check_memory( check_memory_request_c_ls_reward_scroll,
+			"request.c: ls_reward_scroll" );
+	check_memory( check_memory_request_c_g_request_pre,
+			"request.c: g_request pre" );
+	check_memory( check_memory_request_c_g_request,
+			"request.c: g_request" );
+	check_memory( check_memory_request_c_ls_menu_request,
+			"request.c: ls_menu_request" );
+}
