@@ -25,7 +25,7 @@
 *   59 Temple Place, Suite 330, Boston, MA 02111-1307, USA
 * ؼ񤤤Ƥ
 * 
-* $Id: scene.c,v 1.17 2009/06/03 19:25:12 bowkenken Exp $
+* $Id: scene.c,v 1.19 2009/07/31 19:01:24 bowkenken Exp $
 ***************************************************************/
 
 /***************************************************************
@@ -40,7 +40,9 @@
 ***************************************************************/
 
 static scene_n_t	scene_n;
+check_memory_def( check_memory_scene_c_scene_n )
 static last_scene_n_t	last_scene_n;
+check_memory_def( check_memory_scene_c_last_scene_n )
 
 /***************************************************************
 * ν
@@ -491,6 +493,8 @@ bool_t	chk_scene_group( scene_group_n_t group_n )
 	case SCENE_N_ENDING_SPACE:
 		if( group_n == SCENE_GROUP_N_ENDING )
 			return TRUE;
+		if( group_n == SCENE_GROUP_N_SPACE )
+			return TRUE;
 		if( group_n == SCENE_GROUP_N_DEMO )
 			return TRUE;
 		if( group_n == SCENE_GROUP_N_CAN_NOT_SKIP )
@@ -499,6 +503,8 @@ bool_t	chk_scene_group( scene_group_n_t group_n )
 	case SCENE_N_ENDING_STAFF_ROLL:
 		if( group_n == SCENE_GROUP_N_ENDING )
 			return TRUE;
+		if( group_n == SCENE_GROUP_N_SPACE )
+			return TRUE;
 		if( group_n == SCENE_GROUP_N_DEMO )
 			return TRUE;
 		if( group_n == SCENE_GROUP_N_CAN_NOT_SKIP )
@@ -507,6 +513,8 @@ bool_t	chk_scene_group( scene_group_n_t group_n )
 	case SCENE_N_ENDING_END:
 		if( group_n == SCENE_GROUP_N_ENDING )
 			return TRUE;
+		if( group_n == SCENE_GROUP_N_SPACE )
+			return TRUE;
 		if( group_n == SCENE_GROUP_N_GAME_END )
 			return TRUE;
 		if( group_n == SCENE_GROUP_N_DEMO )
@@ -524,3 +532,15 @@ bool_t	chk_scene_group( scene_group_n_t group_n )
 
 	return FALSE;
 }
+
+/***************************************************************
+* ꡼å
+***************************************************************/
+
+void	check_memory_scene_c( void )
+{
+	check_memory( check_memory_scene_c_scene_n,
+			"scene.c: scene_n" );
+	check_memory( check_memory_scene_c_last_scene_n,
+			"scene.c: last_scene_n" );
+}
