@@ -25,7 +25,7 @@
 *   59 Temple Place, Suite 330, Boston, MA 02111-1307, USA
 * ؼ񤤤Ƥ
 * 
-* $Id: skill.c,v 1.12 2009/02/17 00:56:59 bowkenken Exp $
+* $Id: skill.c,v 1.14 2009/06/26 16:58:16 bowkenken Exp $
 ***************************************************************/
 
 /***************************************************************
@@ -41,6 +41,7 @@
 
 skill_kind_t	skill_group_tab[SKILL_GROUP_KIND_MAX_N]
 	[SKILL_PER_GROUP_MAX_N + 1];
+check_memory_def( check_memory_skill_c_skill_group_tab )
 
 #include	"skill-tab.h"
 
@@ -470,7 +471,7 @@ long	calc_skill_phalanx_mbr_n( mbr_t *mbr )
 
 const char	*get_skill_hint( skill_kind_t skill_kind )
 {
-	static char	str[SKILL_HINT_MAX_LEN + 1];
+	static char	str[SKILL_HINT_MAX_BYTE + 1];
 
 	str[0] = '\0';
 
@@ -486,72 +487,72 @@ const char	*get_skill_hint( skill_kind_t skill_kind )
 
 	/* SKILL_GROUP_KIND_FIGHT, */
 	case SKILL_KIND_ATTACKER:
-		sn_printf( str, SKILL_HINT_MAX_LEN,
+		sn_printf( str, SKILL_HINT_MAX_BYTE,
 				MSG_SKILL_HINT_ATTACKER,
 				SKILL_FIGHT_A_BASE_RATE,
 				SKILL_FIGHT_A_SUB_BASE_RATE );
 		break;
 	case SKILL_KIND_BERSERKER:
-		sn_printf( str, SKILL_HINT_MAX_LEN,
+		sn_printf( str, SKILL_HINT_MAX_BYTE,
 				MSG_SKILL_HINT_BERSERKER,
 				SKILL_FIGHT_A_BASE_RATE,
 				SKILL_FIGHT_A_SUB_BASE_RATE );
 		break;
 	case SKILL_KIND_DEFENDER:
-		sn_printf( str, SKILL_HINT_MAX_LEN,
+		sn_printf( str, SKILL_HINT_MAX_BYTE,
 				MSG_SKILL_HINT_DEFENDER,
 				SKILL_FIGHT_A_BASE_RATE,
 				SKILL_FIGHT_A_SUB_BASE_RATE );
 		break;
 	case SKILL_KIND_SENTINEL:
-		sn_printf( str, SKILL_HINT_MAX_LEN,
+		sn_printf( str, SKILL_HINT_MAX_BYTE,
 				MSG_SKILL_HINT_SENTINEL,
 				SKILL_FIGHT_B_BASE_RATE );
 		break;
 	case SKILL_KIND_ASSASSIN:
-		sn_printf( str, SKILL_HINT_MAX_LEN,
+		sn_printf( str, SKILL_HINT_MAX_BYTE,
 				MSG_SKILL_HINT_ASSASSIN,
 				SKILL_FIGHT_B_BASE_RATE );
 		break;
 	case SKILL_KIND_AEGIS:
-		sn_printf( str, SKILL_HINT_MAX_LEN,
+		sn_printf( str, SKILL_HINT_MAX_BYTE,
 				MSG_SKILL_HINT_AEGIS,
 				SKILL_FIGHT_B_BASE_RATE );
 		break;
 	case SKILL_KIND_SIEGE:
-		sn_printf( str, SKILL_HINT_MAX_LEN,
+		sn_printf( str, SKILL_HINT_MAX_BYTE,
 				MSG_SKILL_HINT_SIEGE,
 				SKILL_FIGHT_C_MUL_RATE );
 		break;
 	case SKILL_KIND_PHALANX:
-		sn_printf( str, SKILL_HINT_MAX_LEN,
+		sn_printf( str, SKILL_HINT_MAX_BYTE,
 				MSG_SKILL_HINT_PHALANX,
 				SKILL_FIGHT_C_MUL_RATE );
 		break;
 
 	/* SKILL_GROUP_KIND_COMBO, */
 	case SKILL_KIND_DOUBLE_ATTACK:
-		sn_printf( str, SKILL_HINT_MAX_LEN,
+		sn_printf( str, SKILL_HINT_MAX_BYTE,
 				MSG_SKILL_HINT_DOUBLE_ATTACK,
 				SKILL_FIG_BASE_RATE );
 		break;
 	case SKILL_KIND_COMBO:
-		sn_printf( str, SKILL_HINT_MAX_LEN,
+		sn_printf( str, SKILL_HINT_MAX_BYTE,
 				MSG_SKILL_HINT_COMBO,
 				SKILL_MON_BASE_RATE );
 		break;
 	case SKILL_KIND_RAPID_SHOOT:
-		sn_printf( str, SKILL_HINT_MAX_LEN,
+		sn_printf( str, SKILL_HINT_MAX_BYTE,
 				MSG_SKILL_HINT_RAPID_SHOOT,
 				SKILL_HUN_BASE_RATE );
 		break;
 	case SKILL_KIND_COUNTER:
-		sn_printf( str, SKILL_HINT_MAX_LEN,
+		sn_printf( str, SKILL_HINT_MAX_BYTE,
 				MSG_SKILL_HINT_COUNTER,
 				SKILL_COUNTER_BASE_RATE );
 		break;
 	case SKILL_KIND_TWO_SWORD_FENCING:
-		sn_printf( str, SKILL_HINT_MAX_LEN,
+		sn_printf( str, SKILL_HINT_MAX_BYTE,
 				MSG_SKILL_HINT_TWO_SWORD_FENCING,
 				SKILL_TWO_SWORD_FENCING_BASE_RATE );
 		break;
@@ -566,7 +567,7 @@ const char	*get_skill_hint( skill_kind_t skill_kind )
 	case SKILL_KIND_DAM_ACID:
 	case SKILL_KIND_DAM_ELEC:
 	case SKILL_KIND_DAM_POIS:
-		sn_printf( str, SKILL_HINT_MAX_LEN,
+		sn_printf( str, SKILL_HINT_MAX_BYTE,
 				MSG_SKILL_HINT_DAM,
 				SKILL_DAM_BASE_RATE );
 		break;
@@ -581,7 +582,7 @@ const char	*get_skill_hint( skill_kind_t skill_kind )
 	case SKILL_KIND_RESI_ACID:
 	case SKILL_KIND_RESI_ELEC:
 	case SKILL_KIND_RESI_POIS:
-		sn_printf( str, SKILL_HINT_MAX_LEN,
+		sn_printf( str, SKILL_HINT_MAX_BYTE,
 				MSG_SKILL_HINT_RESI,
 				SKILL_RESI_BASE_RATE );
 		break;
@@ -608,14 +609,14 @@ const char	*get_skill_hint( skill_kind_t skill_kind )
 	case SKILL_KIND_STAT_IRON_BODY:
 	case SKILL_KIND_STAT_PASSWALL:
 	case SKILL_KIND_STAT_SENSE_INVISIBLE:
-		sn_printf( str, SKILL_HINT_MAX_LEN,
+		sn_printf( str, SKILL_HINT_MAX_BYTE,
 				MSG_SKILL_HINT_STAT );
 				/* SKILL_STAT_BASE_N */
 		break;
 
 	/* SKILL_GROUP_KIND_MISC, */
 	case SKILL_KIND_RUN_AWAY:
-		sn_printf( str, SKILL_HINT_MAX_LEN,
+		sn_printf( str, SKILL_HINT_MAX_BYTE,
 				MSG_SKILL_HINT_RUN_AWAY,
 				SKILL_RUN_AWAY_BASE_N );
 		break;
@@ -1106,3 +1107,13 @@ skill_kind_t	cv_stat_to_skill_stat( flg_stat_t stat )
 
 	return SKILL_KIND_NULL;
 }
+
+/***************************************************************
+* ꡼å
+***************************************************************/
+
+void	check_memory_skill_c( void )
+{
+	check_memory( check_memory_skill_c_skill_group_tab,
+			"skill.c: skill_group_tab" );
+}
