@@ -25,7 +25,7 @@
 *   59 Temple Place, Suite 330, Boston, MA 02111-1307, USA
 * ؼ񤤤Ƥ
 * 
-* $Id: spell-kind.h,v 1.15 2009/08/08 21:02:29 bowkenken Exp $
+* $Id: spell-kind.h,v 1.16 2009/09/03 11:26:34 bowkenken Exp $
 ***************************************************************/
 
 #ifndef	SPELL_KIND_H
@@ -240,6 +240,19 @@ typedef enum {
 	SPELL_KIND_MAX_N,
 } spell_kind_t;
 
+/* STRINGED -  */
+#define	SPELL_KIND_BAR_CURE_MIN_N	SPELL_KIND_SONG_CURE_HP
+#define	SPELL_KIND_BAR_CURE_MAX_N	SPELL_KIND_SONG_CURE_MP
+/* WOODWIND - ǽͶ */
+#define	SPELL_KIND_BAR_STRENGTHEN_ABL_MIN_N	SPELL_KIND_SONG_SHARPNESS
+#define	SPELL_KIND_BAR_STRENGTHEN_ABL_MAX_N	SPELL_KIND_SONG_ATTRACTIVE
+/* BRASS - ǽͼ */
+#define	SPELL_KIND_BAR_WEAKEN_ABL_MIN_N	SPELL_KIND_SONG_DULLNESS
+#define	SPELL_KIND_BAR_WEAKEN_ABL_MAX_N	SPELL_KIND_SONG_UNATTRACTIVE
+/* PERCUSSION -  */
+#define	SPELL_KIND_BAR_RESI_STAT_MIN_N	SPELL_KIND_SONG_RESI_STAT_STONE
+#define	SPELL_KIND_BAR_RESI_STAT_MAX_N	SPELL_KIND_SONG_RESI_STAT_DRUNK
+
 /* ʸθϰ */
 
 typedef enum {
