@@ -1,6 +1,6 @@
 /***************************************************************
 * L&L - Labyrinths & Legends
-* Copyright (c) 1993-2008 YOSHIMURA Tomohiko All rights reserved.
+* Copyright (c) 1993-2009 YOSHIMURA Tomohiko All rights reserved.
 * 
 * Created by BowKenKen
 *   URL: https://sourceforge.jp/projects/lnl/
@@ -25,7 +25,7 @@
 *   59 Temple Place, Suite 330, Boston, MA 02111-1307, USA
 * ؼ񤤤Ƥ
 * 
-* $Id: tmenu-tab.h,v 1.24 2008/09/21 00:58:16 bowkenken Exp $
+* $Id: tmenu-tab.h,v 1.28 2009/07/20 16:35:24 bowkenken Exp $
 ***************************************************************/
 
 #ifndef	TMENU_TAB_H
@@ -176,7 +176,7 @@ menu_t	ls_menu_magic_guild[] = {
 		NULL, NULL,
 		FLG_NULL,
 	},
-/* [ˡ] ¾ */
+/* [ˡ]  */
 	{
 		"/magic guild/MAG/title misc",
 		"<Title>",
@@ -397,16 +397,6 @@ menu_t	ls_menu_magic_guild[] = {
 		FLG_NULL,
 	},
 
-	{
-		"/magic guild/MAG/detect_magic",
-		"<Branch>",
-		'\0',
-		"",
-		N_MSG_SPELL_DETECT_MAGIC, "",
-		cb_menu_magic_guild, (void *)SPELL_KIND_DETECT_MAGIC,
-		FLG_NULL,
-	},
-
 	{
 		"/magic guild/MAG/detect_item",
 		"<Branch>",
@@ -437,6 +427,16 @@ menu_t	ls_menu_magic_guild[] = {
 		FLG_NULL,
 	},
 
+	{
+		"/magic guild/MAG/detect_magic",
+		"<Branch>",
+		'\0',
+		"",
+		N_MSG_SPELL_DETECT_MAGIC, "",
+		cb_menu_magic_guild, (void *)SPELL_KIND_DETECT_MAGIC,
+		FLG_NULL,
+	},
+
 	{
 		"/magic guild/MAG/detect_monster",
 		"<Branch>",
@@ -476,7 +476,7 @@ menu_t	ls_menu_magic_guild[] = {
 		NULL, NULL,
 		FLG_NULL,
 	},
-/* [ˡ] ƥѲ */
+/* [ˡ] Ѳ */
 	{
 		"/magic guild/MAG/title change status",
 		"<Title>",
@@ -536,7 +536,37 @@ menu_t	ls_menu_magic_guild[] = {
 		cb_menu_magic_guild, (void *)SPELL_KIND_PASSWALL,
 		FLG_NULL,
 	},
-/* [ˡ] üե饰Ѳ */
+
+	{
+		"/magic guild/MAG/no_learn change status",
+		"<Item>",
+		'Z',
+		"",
+		N_MSG_SPELL_NO_LEARN, "",
+		cb_menu_magic_guild_no_learn, NULL,
+		FLG_NULL,
+	},
+
+	{
+		"/magic guild/MAG/--",
+		"<PageSeparator>",
+		'\0',
+		"",
+		N_MSG_NULL, "",
+		NULL, NULL,
+		FLG_NULL,
+	},
+/* [ˡ] üѲ */
+	{
+		"/magic guild/MAG/title change special",
+		"<Title>",
+		'\0',
+		"",
+		N_MSG_MAG_CHANGE_SPECIAL, "",
+		NULL, NULL,
+		FLG_NULL,
+	},
+
 	{
 		"/magic guild/MAG/polymorph_other",
 		"<Branch>",
@@ -568,7 +598,7 @@ menu_t	ls_menu_magic_guild[] = {
 	},
 
 	{
-		"/magic guild/MAG/no_learn change status",
+		"/magic guild/MAG/no_learn change special",
 		"<Item>",
 		'Z',
 		"",
@@ -687,6 +717,16 @@ menu_t	ls_menu_magic_guild[] = {
 		FLG_NULL,
 	},
 
+	{
+		"/magic guild/SOR/word_of_destruction",
+		"<Branch>",
+		'\0',
+		"",
+		N_MSG_SPELL_WORD_OF_DESTRUCTION, "",
+		cb_menu_magic_guild, (void *)SPELL_KIND_WORD_OF_DESTRUCTION,
+		FLG_NULL,
+	},
+
 	{
 		"/magic guild/SOR/no_learn attack",
 		"<Item>",
@@ -717,16 +757,6 @@ menu_t	ls_menu_magic_guild[] = {
 		FLG_NULL,
 	},
 
-	{
-		"/magic guild/SOR/magic_shield",
-		"<Branch>",
-		'\0',
-		"",
-		N_MSG_SPELL_MAGIC_SHIELD, "",
-		cb_menu_magic_guild, (void *)SPELL_KIND_MAGIC_SHIELD,
-		FLG_NULL,
-	},
-
 	{
 		"/magic guild/SOR/mage_armor",
 		"<Branch>",
@@ -737,6 +767,16 @@ menu_t	ls_menu_magic_guild[] = {
 		FLG_NULL,
 	},
 
+	{
+		"/magic guild/SOR/magic_shield",
+		"<Branch>",
+		'\0',
+		"",
+		N_MSG_SPELL_MAGIC_SHIELD, "",
+		cb_menu_magic_guild, (void *)SPELL_KIND_MAGIC_SHIELD,
+		FLG_NULL,
+	},
+
 	{
 		"/magic guild/SOR/stoneskin",
 		"<Branch>",
@@ -1046,7 +1086,7 @@ menu_t	ls_menu_magic_guild[] = {
 		cb_menu_magic_guild, (void *)SPELL_KIND_POWER_UP_HP,
 		FLG_NULL,
 	},
-/* [ˡ]  */
+
 	{
 		"/magic guild/ENC/haste",
 		"<Branch>",
@@ -1186,7 +1226,7 @@ menu_t	ls_menu_magic_guild[] = {
 		cb_menu_magic_guild, (void *)SPELL_KIND_ENERGY_DRAIN,
 		FLG_NULL,
 	},
-/* [ˡ]  */
+
 	{
 		"/magic guild/ENC/slow",
 		"<Branch>",
@@ -1317,6 +1357,16 @@ menu_t	ls_menu_magic_guild[] = {
 		FLG_NULL,
 	},
 
+	{
+		"/magic guild/SUM/summon_random",
+		"<Branch>",
+		'\0',
+		"",
+		N_MSG_SPELL_SUMMON_RANDOM, "",
+		cb_menu_magic_guild, (void *)SPELL_KIND_SUMMON_RANDOM,
+		FLG_NULL,
+	},
+
 	{
 		"/magic guild/SUM/create_undead",
 		"<Branch>",
@@ -1513,6 +1563,15 @@ menu_t	ls_menu_bar[] = {
 		cb_menu_bar_edit_class, NULL,
 		FLG_NULL,
 	},
+	{
+		"/bar/form/edit class/edit skill",
+		"<Branch>",
+		'S',
+		"",
+		N_MSG_MENU_BAR_EDIT_SKILL, "",
+		cb_menu_bar_edit_skill, NULL,
+		FLG_NULL,
+	},
 	{
 		"/bar/form/edit class/new class",
 		"<OpenWinItem>",
@@ -1942,4 +2001,7 @@ menu_t	ls_menu_pet_shop_buy[
 menu_t	ls_menu_navi[1 + 1 + SHOP_N_MAX_N + 1];
 menu_t	ls_menu_auto_sale[1 + 1 + MBR_ITEM_MAX_N + 1 + 1];
 
+menu_t	ls_menu_sel_skill[
+	1 + 1 + (SKILL_KIND_MAX_N + SKILL_GROUP_KIND_MAX_N * 3) + 1];
+
 #endif	/* TMENU_TAB_H */
