@@ -25,7 +25,7 @@
 *   59 Temple Place, Suite 330, Boston, MA 02111-1307, USA
 * ؼ񤤤Ƥ
 * 
-* $Id: tmenu.c,v 1.153 2009/07/12 05:41:25 bowkenken Exp $
+* $Id: tmenu.c,v 1.154 2009/09/04 15:26:28 bowkenken Exp $
 ***************************************************************/
 
 #define	TMENU_C
@@ -213,7 +213,7 @@ char	*cb_menu_temple_init( menu_t **pp, menu_t **dflt )
 	for( p = *pp; p->path[0] != '\0'; p++ ){
 		long	tmp_len;
 
-		tmp_len = str_len_std( MSG( p->n_msg ) );
+		tmp_len = str_len_draw( MSG( p->n_msg ) );
 		max_len = max_l( max_len, tmp_len );
 	}
 
@@ -833,7 +833,7 @@ char	*menu_shop( shop_n_t shop_n, mbr_t *mbr, char *str_goto )
 		ls_art[ls_art_n] = art;
 		ls_art_n++;
 
-		len = str_len_std( art->art_name );
+		len = str_len_draw( art->art_name );
 		max_len = max_l( len, max_len );
 
 		/* menu */
@@ -887,15 +887,22 @@ char	*menu_shop( shop_n_t shop_n, mbr_t *mbr, char *str_goto )
 	/* ̾ʤĤ */
 
 	for( i = 0, j = 0; i < k; i++ ){
+		gold_t	price;
+		const char	*str_gold;
+		long	len;
+
 		if( ls[i].arg == NULL )
 			continue;
 
+		price = get_price( g_shop_n, ls_art[j], g_deal_kind );
+		str_gold = fmt_gold( price );
+		len = get_pading_len( ls_art[j]->art_name, max_len );
+
 		sn_printf( ls[i].msg,
 				MENU_MSG_MAX_BYTE,
 				MSG_FMT_ART_NAME,
-				max_len, ls_art[j]->art_name,
-				fmt_gold( get_price(
-				g_shop_n, ls_art[j], g_deal_kind ) ) );
+				len, ls_art[j]->art_name,
+				str_gold );
 		j++;
 	}
 
@@ -3367,6 +3374,9 @@ char	*cb_menu_magic_guild_init( menu_t **pp, menu_t **dflt )
 {
 	menu_t	*ls, *p;
 	unsigned char	key;
+	spell_kind_t	kind;
+	spell_tab_t	*tab;
+	long	len, max_len;
 	bool_t	flg_no_enter;
 	gold_t	gold;
 	long	i;
@@ -3376,6 +3386,19 @@ char	*cb_menu_magic_guild_init( menu_t **pp, menu_t **dflt )
 
 	ls = *pp;
 
+	max_len = 1;
+	for( i = 0; i < LOOP_MAX_1000; i++ ){
+		if( ls[i].path[0] == '\0' )
+			break;
+
+		kind = (spell_kind_t)(long)(ls[i].arg);
+		tab = get_spell_tab( kind );
+		if( tab != NULL ){
+			len = str_len_draw( tab->name );
+			max_len = max_l( len, max_len );
+		}
+	}
+
 	p = srch_menu( *pp, "title" );
 	if( p == NULL )
 		return STR_MENU_ERR;
@@ -3386,9 +3409,6 @@ char	*cb_menu_magic_guild_init( menu_t **pp, menu_t **dflt )
 
 	key = 'A';
 	for( i = 0; i < LOOP_MAX_1000; i++ ){
-		spell_kind_t	kind;
-		spell_tab_t	*tab;
-
 		if( ls[i].path[0] == '\0' )
 			break;
 		if( strcmp( ls[i].kind, "<PageSeparator>" ) == 0 ){
@@ -3408,18 +3428,20 @@ char	*cb_menu_magic_guild_init( menu_t **pp, menu_t **dflt )
 		/**/
 
 		kind = (spell_kind_t)(long)(ls[i].arg);
-
 		tab = get_spell_tab( kind );
+
 		if( tab == NULL ){
 			gold = 0;
 			sn_printf( ls[i].msg, MENU_MSG_MAX_BYTE,
 					MSG_FMT_MENU_MAGIC_GUILD,
-					"", 0, fmt_gold( 0 ) );
+					0, "", 0,
+					fmt_gold( 0 ) );
 		} else {
+			len = get_pading_len( tab->name, max_len );
 			gold = get_price_spell( kind );
 			sn_printf( ls[i].msg, MENU_MSG_MAX_BYTE,
 					MSG_FMT_MENU_MAGIC_GUILD,
-					tab->name, tab->lev,
+					len, tab->name, tab->lev,
 					fmt_gold( gold ) );
 		}
 
@@ -4048,6 +4070,8 @@ char	*cb_menu_pet_shop_remove_sel( menu_t **pp, menu_t **dflt )
 char	*cb_menu_pet_shop_buy( menu_t **pp, menu_t **dflt )
 {
 	art_ls_pet_shop_t	*art_ls_pet_shop;
+	long	len, max_len;
+	const char	*name;
 	menu_t	*ls;
 	long	k;
 	long	i, max_n;
@@ -4085,6 +4109,16 @@ char	*cb_menu_pet_shop_buy( menu_t **pp, menu_t **dflt )
 	ls[k].flg = FLG_NULL;
 	k++;
 
+	max_len = 1;
+	for( i = 0; i < max_n; i++ ){
+		if( art_ls_pet_shop[i].kind == MNSTR_KIND_NULL )
+			break;
+
+		name = get_mnstr_name( art_ls_pet_shop[i].kind );
+		len = str_len_draw( name );
+		max_len = max_l( len, max_len );
+	}
+
 	for( i = 0; i < max_n; i++ ){
 		if( art_ls_pet_shop[i].kind == MNSTR_KIND_NULL )
 			break;
@@ -4113,9 +4147,11 @@ char	*cb_menu_pet_shop_buy( menu_t **pp, menu_t **dflt )
 		ls[k].accel_key = key;
 		ls[k].short_key[0] = '\0';
 		ls[k].n_msg = N_MSG_NULL,
+		name = get_mnstr_name( art_ls_pet_shop[i].kind );
+		len = get_pading_len( name, max_len );
 		sn_printf( ls[k].msg, MENU_MSG_MAX_BYTE,
 				MSG_FMT_MENU_PET_SHOP,
-				get_mnstr_name( art_ls_pet_shop[i].kind ),
+				len, name,
 				fmt_gold( art_ls_pet_shop[i].price ) );
 		ls[k].call_back = cb_menu_pet_shop_buy_sel;
 		ls[k].arg = (void *)i;
@@ -4402,11 +4438,11 @@ bool_t	set_menu_auto_sale( menu_t *ls, mbr_t *mbr )
 		ls[k].accel_key = toupper( (char)('A' + i) );
 		ls[k].short_key[0] = '\0';
 		ls[k].n_msg = N_MSG_NULL,
+		len = get_pading_len( item->art_name, max_len );
 		sn_printf( ls[k].msg,
 				MENU_MSG_MAX_BYTE,
 				MSG_FMT_ART_NAME,
-				max_len,
-				item->art_name,
+				len, item->art_name,
 				fmt_gold( price ) );
 		ls[k].call_back = cb_menu_auto_sale_chk;
 		ls[k].arg = (void *)item;
