@@ -25,7 +25,7 @@
 *   59 Temple Place, Suite 330, Boston, MA 02111-1307, USA
 * ؼ񤤤Ƥ
 * 
-* $Id: town.c,v 1.155 2009/06/21 12:39:41 bowkenken Exp $
+* $Id: town.c,v 1.159 2009/07/23 13:16:43 bowkenken Exp $
 ***************************************************************/
 
 #define	TOWN_C
@@ -38,6 +38,7 @@
 #define	TOWNER_AVE_N	64
 
 #define	FLOOR_IS_FIND_NIGHT	1
+#define	FLG_RESET_RESI_STAY_INN	0
 
 /***************************************************************
 * ŹαĶȻ
@@ -200,6 +201,7 @@
 #define	DISCOUNT_QUEUE_R	4
 
 discount_queue_t	g_discount_queue;
+check_memory_def( check_memory_town_c_g_discount_queue )
 
 /***************************************************************
 * ¾
@@ -227,9 +229,13 @@ discount_queue_t	g_discount_queue;
 ***************************************************************/
 
 static town_ptn_t	town_ptn, town_ptn_trans;
+check_memory_def( check_memory_town_c_town_ptn )
 
 static long	g_morning_glow_n, g_evening_glow_n;
+check_memory_def( check_memory_town_c_g_morning_glow_n )
+
 static bool_t	g_flg_night;
+check_memory_def( check_memory_town_c_g_flg_night )
 
 /***************************************************************
 * 
@@ -2063,11 +2069,13 @@ void	stay_inn( bool_t flg_short_stay, bool_t flg_mews )
 		/* MP  */
 		mbr->abl.mp.n = mbr->abl.mp.max;
 
-		/* ͤꥻå */
-		for( j = 0; j < RESI_KIND_MAX_N; j++ ){
-			reset_mbr_resi( mbr );
-			mbr->resi[j].n = get_resi_max(
-					mbr, (resi_kind_t)j );
+		if( FLG_RESET_RESI_STAY_INN ){
+			/* ͤꥻå */
+			for( j = 0; j < RESI_KIND_MAX_N; j++ ){
+				reset_mbr_resi( mbr );
+				mbr->resi[j].n = get_resi_max(
+						mbr, (resi_kind_t)j );
+			}
 		}
 
 		/* 줤 */
@@ -2149,6 +2157,8 @@ void	stay_inn( bool_t flg_short_stay, bool_t flg_mews )
 
 void	take_bath( chr_t *chr )
 {
+	long	j;
+
 	if( chr == NULL )
 		return;
 
@@ -2171,6 +2181,14 @@ void	take_bath( chr_t *chr )
 				MSG_WORDS_CHR_IS_MOLESTED_FAMALE,
 				MSG_WORDS_CHR_IS_MOLESTED_MALE );
 	}
+
+	/* ͤꥻå */
+
+	for( j = 0; j < RESI_KIND_MAX_N; j++ ){
+		reset_mbr_resi( chr );
+		chr->resi[j].n = get_resi_max(
+				chr, (resi_kind_t)j );
+	}
 }
 
 /***************************************************************
@@ -2829,7 +2847,7 @@ gold_t	get_price_temple_remove_curse( mbr_t *mbr )
 
 	price = PRICE_TEMPLE_REMOVE_CURSE;
 
-	price = discount( price, SHOP_N_INN, DEAL_KIND_BUY );
+	price = discount( price, SHOP_N_TEMPLE, DEAL_KIND_BUY );
 
 	return price;
 }
@@ -2858,7 +2876,7 @@ gold_t	get_price_temple_cure_status( mbr_t *mbr )
 
 	price += price * smoker / _100_PERCENT;
 
-	price = discount( price, SHOP_N_INN, DEAL_KIND_BUY );
+	price = discount( price, SHOP_N_TEMPLE, DEAL_KIND_BUY );
 
 	return price;
 }
@@ -2887,7 +2905,7 @@ gold_t	get_price_temple_resurrection( mbr_t *mbr )
 
 	price += price * smoker / _100_PERCENT;
 
-	price = discount( price, SHOP_N_INN, DEAL_KIND_BUY );
+	price = discount( price, SHOP_N_TEMPLE, DEAL_KIND_BUY );
 
 	return price;
 }
@@ -2908,7 +2926,7 @@ gold_t	get_price_temple_contribution( mbr_t *mbr )
 	if( price < PRICE_TEMPLE_CONTRIBUTION_PRICE_MIN )
 		price = PRICE_TEMPLE_CONTRIBUTION_PRICE_MIN;
 
-	price = discount( price, SHOP_N_INN, DEAL_KIND_BUY );
+	price = discount( price, SHOP_N_TEMPLE, DEAL_KIND_BUY );
 
 	return price;
 }
@@ -3789,3 +3807,19 @@ bool_t	save_town( void )
 
 	return TRUE;
 }
+
+/***************************************************************
+* ꡼å
+***************************************************************/
+
+void	check_memory_town_c( void )
+{
+	check_memory( check_memory_town_c_g_discount_queue,
+			"town.c: g_discount_queue" );
+	check_memory( check_memory_town_c_town_ptn,
+			"town.c: town_ptn" );
+	check_memory( check_memory_town_c_g_morning_glow_n,
+			"town.c: g_morning_glow_n" );
+	check_memory( check_memory_town_c_g_flg_night,
+			"town.c: g_flg_night" );
+}
