@@ -16,6 +16,7 @@ long	inc_day( void );
 long	set_game_date( long year, long month, long day );
 long	set_game_day( long day );
 long	get_game_day( void );
+bool_t	chk_day( void );
 bool_t	chk_morning( void );
 bool_t	chk_evening( void );
 bool_t	chk_night( void );
@@ -25,6 +26,7 @@ char	*get_calendar_str( void );
 char	*get_stat_time_str( void );
 char	*get_day_of_week_name( void );
 day_of_week_t	get_day_of_week( void );
+void	check_memory_turn_c( void );
 
 #ifdef __cplusplus
 }
